
/* Capstone Disassembly Engine, http://www.capstone-engine.org */
/* By Nguyen Anh Quynh <aquynh@gmail.com>, 2013-2019 */

/*===- TableGen'erated file -------------------------------------*- C++ -*-===*|*                                                                            *|
|* Target Instruction Enum Values and Descriptors                             *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifdef GET_INSTRINFO_ENUM
#undef GET_INSTRINFO_ENUM

enum {
	PPC_PHI	= 0,
	PPC_INLINEASM	= 1,
	PPC_CFI_INSTRUCTION	= 2,
	PPC_EH_LABEL	= 3,
	PPC_GC_LABEL	= 4,
	PPC_ANNOTATION_LABEL	= 5,
	PPC_KILL	= 6,
	PPC_EXTRACT_SUBREG	= 7,
	PPC_INSERT_SUBREG	= 8,
	PPC_IMPLICIT_DEF	= 9,
	PPC_SUBREG_TO_REG	= 10,
	PPC_COPY_TO_REGCLASS	= 11,
	PPC_DBG_VALUE	= 12,
	PPC_DBG_LABEL	= 13,
	PPC_REG_SEQUENCE	= 14,
	PPC_COPY	= 15,
	PPC_BUNDLE	= 16,
	PPC_LIFETIME_START	= 17,
	PPC_LIFETIME_END	= 18,
	PPC_STACKMAP	= 19,
	PPC_FENTRY_CALL	= 20,
	PPC_PATCHPOINT	= 21,
	PPC_LOAD_STACK_GUARD	= 22,
	PPC_STATEPOINT	= 23,
	PPC_LOCAL_ESCAPE	= 24,
	PPC_FAULTING_OP	= 25,
	PPC_PATCHABLE_OP	= 26,
	PPC_PATCHABLE_FUNCTION_ENTER	= 27,
	PPC_PATCHABLE_RET	= 28,
	PPC_PATCHABLE_FUNCTION_EXIT	= 29,
	PPC_PATCHABLE_TAIL_CALL	= 30,
	PPC_PATCHABLE_EVENT_CALL	= 31,
	PPC_PATCHABLE_TYPED_EVENT_CALL	= 32,
	PPC_ICALL_BRANCH_FUNNEL	= 33,
	PPC_G_ADD	= 34,
	PPC_G_SUB	= 35,
	PPC_G_MUL	= 36,
	PPC_G_SDIV	= 37,
	PPC_G_UDIV	= 38,
	PPC_G_SREM	= 39,
	PPC_G_UREM	= 40,
	PPC_G_AND	= 41,
	PPC_G_OR	= 42,
	PPC_G_XOR	= 43,
	PPC_G_IMPLICIT_DEF	= 44,
	PPC_G_PHI	= 45,
	PPC_G_FRAME_INDEX	= 46,
	PPC_G_GLOBAL_VALUE	= 47,
	PPC_G_EXTRACT	= 48,
	PPC_G_UNMERGE_VALUES	= 49,
	PPC_G_INSERT	= 50,
	PPC_G_MERGE_VALUES	= 51,
	PPC_G_PTRTOINT	= 52,
	PPC_G_INTTOPTR	= 53,
	PPC_G_BITCAST	= 54,
	PPC_G_LOAD	= 55,
	PPC_G_SEXTLOAD	= 56,
	PPC_G_ZEXTLOAD	= 57,
	PPC_G_STORE	= 58,
	PPC_G_ATOMIC_CMPXCHG_WITH_SUCCESS	= 59,
	PPC_G_ATOMIC_CMPXCHG	= 60,
	PPC_G_ATOMICRMW_XCHG	= 61,
	PPC_G_ATOMICRMW_ADD	= 62,
	PPC_G_ATOMICRMW_SUB	= 63,
	PPC_G_ATOMICRMW_AND	= 64,
	PPC_G_ATOMICRMW_NAND	= 65,
	PPC_G_ATOMICRMW_OR	= 66,
	PPC_G_ATOMICRMW_XOR	= 67,
	PPC_G_ATOMICRMW_MAX	= 68,
	PPC_G_ATOMICRMW_MIN	= 69,
	PPC_G_ATOMICRMW_UMAX	= 70,
	PPC_G_ATOMICRMW_UMIN	= 71,
	PPC_G_BRCOND	= 72,
	PPC_G_BRINDIRECT	= 73,
	PPC_G_INTRINSIC	= 74,
	PPC_G_INTRINSIC_W_SIDE_EFFECTS	= 75,
	PPC_G_ANYEXT	= 76,
	PPC_G_TRUNC	= 77,
	PPC_G_CONSTANT	= 78,
	PPC_G_FCONSTANT	= 79,
	PPC_G_VASTART	= 80,
	PPC_G_VAARG	= 81,
	PPC_G_SEXT	= 82,
	PPC_G_ZEXT	= 83,
	PPC_G_SHL	= 84,
	PPC_G_LSHR	= 85,
	PPC_G_ASHR	= 86,
	PPC_G_ICMP	= 87,
	PPC_G_FCMP	= 88,
	PPC_G_SELECT	= 89,
	PPC_G_UADDE	= 90,
	PPC_G_USUBE	= 91,
	PPC_G_SADDO	= 92,
	PPC_G_SSUBO	= 93,
	PPC_G_UMULO	= 94,
	PPC_G_SMULO	= 95,
	PPC_G_UMULH	= 96,
	PPC_G_SMULH	= 97,
	PPC_G_FADD	= 98,
	PPC_G_FSUB	= 99,
	PPC_G_FMUL	= 100,
	PPC_G_FMA	= 101,
	PPC_G_FDIV	= 102,
	PPC_G_FREM	= 103,
	PPC_G_FPOW	= 104,
	PPC_G_FEXP	= 105,
	PPC_G_FEXP2	= 106,
	PPC_G_FLOG	= 107,
	PPC_G_FLOG2	= 108,
	PPC_G_FNEG	= 109,
	PPC_G_FPEXT	= 110,
	PPC_G_FPTRUNC	= 111,
	PPC_G_FPTOSI	= 112,
	PPC_G_FPTOUI	= 113,
	PPC_G_SITOFP	= 114,
	PPC_G_UITOFP	= 115,
	PPC_G_FABS	= 116,
	PPC_G_GEP	= 117,
	PPC_G_PTR_MASK	= 118,
	PPC_G_BR	= 119,
	PPC_G_INSERT_VECTOR_ELT	= 120,
	PPC_G_EXTRACT_VECTOR_ELT	= 121,
	PPC_G_SHUFFLE_VECTOR	= 122,
	PPC_G_BSWAP	= 123,
	PPC_G_ADDRSPACE_CAST	= 124,
	PPC_G_BLOCK_ADDR	= 125,
	PPC_CFENCE8	= 126,
	PPC_CLRLSLDI	= 127,
	PPC_CLRLSLDIo	= 128,
	PPC_CLRLSLWI	= 129,
	PPC_CLRLSLWIo	= 130,
	PPC_CLRRDI	= 131,
	PPC_CLRRDIo	= 132,
	PPC_CLRRWI	= 133,
	PPC_CLRRWIo	= 134,
	PPC_CP_COPY_FIRST	= 135,
	PPC_CP_COPYx	= 136,
	PPC_CP_PASTE_LAST	= 137,
	PPC_CP_PASTEx	= 138,
	PPC_DCBFL	= 139,
	PPC_DCBFLP	= 140,
	PPC_DCBFx	= 141,
	PPC_DCBTCT	= 142,
	PPC_DCBTDS	= 143,
	PPC_DCBTSTCT	= 144,
	PPC_DCBTSTDS	= 145,
	PPC_DCBTSTT	= 146,
	PPC_DCBTSTx	= 147,
	PPC_DCBTT	= 148,
	PPC_DCBTx	= 149,
	PPC_DFLOADf32	= 150,
	PPC_DFLOADf64	= 151,
	PPC_DFSTOREf32	= 152,
	PPC_DFSTOREf64	= 153,
	PPC_EXTLDI	= 154,
	PPC_EXTLDIo	= 155,
	PPC_EXTLWI	= 156,
	PPC_EXTLWIo	= 157,
	PPC_EXTRDI	= 158,
	PPC_EXTRDIo	= 159,
	PPC_EXTRWI	= 160,
	PPC_EXTRWIo	= 161,
	PPC_INSLWI	= 162,
	PPC_INSLWIo	= 163,
	PPC_INSRDI	= 164,
	PPC_INSRDIo	= 165,
	PPC_INSRWI	= 166,
	PPC_INSRWIo	= 167,
	PPC_LAx	= 168,
	PPC_LIWAX	= 169,
	PPC_LIWZX	= 170,
	PPC_RLWIMIbm	= 171,
	PPC_RLWIMIobm	= 172,
	PPC_RLWINMbm	= 173,
	PPC_RLWINMobm	= 174,
	PPC_RLWNMbm	= 175,
	PPC_RLWNMobm	= 176,
	PPC_ROTRDI	= 177,
	PPC_ROTRDIo	= 178,
	PPC_ROTRWI	= 179,
	PPC_ROTRWIo	= 180,
	PPC_SLDI	= 181,
	PPC_SLDIo	= 182,
	PPC_SLWI	= 183,
	PPC_SLWIo	= 184,
	PPC_SPILLTOVSR_LD	= 185,
	PPC_SPILLTOVSR_LDX	= 186,
	PPC_SPILLTOVSR_ST	= 187,
	PPC_SPILLTOVSR_STX	= 188,
	PPC_SRDI	= 189,
	PPC_SRDIo	= 190,
	PPC_SRWI	= 191,
	PPC_SRWIo	= 192,
	PPC_STIWX	= 193,
	PPC_SUBI	= 194,
	PPC_SUBIC	= 195,
	PPC_SUBICo	= 196,
	PPC_SUBIS	= 197,
	PPC_SUBPCIS	= 198,
	PPC_XFLOADf32	= 199,
	PPC_XFLOADf64	= 200,
	PPC_XFSTOREf32	= 201,
	PPC_XFSTOREf64	= 202,
	PPC_ADD4	= 203,
	PPC_ADD4TLS	= 204,
	PPC_ADD4o	= 205,
	PPC_ADD8	= 206,
	PPC_ADD8TLS	= 207,
	PPC_ADD8TLS_	= 208,
	PPC_ADD8o	= 209,
	PPC_ADDC	= 210,
	PPC_ADDC8	= 211,
	PPC_ADDC8o	= 212,
	PPC_ADDCo	= 213,
	PPC_ADDE	= 214,
	PPC_ADDE8	= 215,
	PPC_ADDE8o	= 216,
	PPC_ADDEo	= 217,
	PPC_ADDI	= 218,
	PPC_ADDI8	= 219,
	PPC_ADDIC	= 220,
	PPC_ADDIC8	= 221,
	PPC_ADDICo	= 222,
	PPC_ADDIS	= 223,
	PPC_ADDIS8	= 224,
	PPC_ADDISdtprelHA	= 225,
	PPC_ADDISdtprelHA32	= 226,
	PPC_ADDISgotTprelHA	= 227,
	PPC_ADDIStlsgdHA	= 228,
	PPC_ADDIStlsldHA	= 229,
	PPC_ADDIStocHA	= 230,
	PPC_ADDIdtprelL	= 231,
	PPC_ADDIdtprelL32	= 232,
	PPC_ADDItlsgdL	= 233,
	PPC_ADDItlsgdL32	= 234,
	PPC_ADDItlsgdLADDR	= 235,
	PPC_ADDItlsgdLADDR32	= 236,
	PPC_ADDItlsldL	= 237,
	PPC_ADDItlsldL32	= 238,
	PPC_ADDItlsldLADDR	= 239,
	PPC_ADDItlsldLADDR32	= 240,
	PPC_ADDItocL	= 241,
	PPC_ADDME	= 242,
	PPC_ADDME8	= 243,
	PPC_ADDME8o	= 244,
	PPC_ADDMEo	= 245,
	PPC_ADDPCIS	= 246,
	PPC_ADDZE	= 247,
	PPC_ADDZE8	= 248,
	PPC_ADDZE8o	= 249,
	PPC_ADDZEo	= 250,
	PPC_ADJCALLSTACKDOWN	= 251,
	PPC_ADJCALLSTACKUP	= 252,
	PPC_AND	= 253,
	PPC_AND8	= 254,
	PPC_AND8o	= 255,
	PPC_ANDC	= 256,
	PPC_ANDC8	= 257,
	PPC_ANDC8o	= 258,
	PPC_ANDCo	= 259,
	PPC_ANDISo	= 260,
	PPC_ANDISo8	= 261,
	PPC_ANDIo	= 262,
	PPC_ANDIo8	= 263,
	PPC_ANDIo_1_EQ_BIT	= 264,
	PPC_ANDIo_1_EQ_BIT8	= 265,
	PPC_ANDIo_1_GT_BIT	= 266,
	PPC_ANDIo_1_GT_BIT8	= 267,
	PPC_ANDo	= 268,
	PPC_ATOMIC_CMP_SWAP_I16	= 269,
	PPC_ATOMIC_CMP_SWAP_I32	= 270,
	PPC_ATOMIC_CMP_SWAP_I64	= 271,
	PPC_ATOMIC_CMP_SWAP_I8	= 272,
	PPC_ATOMIC_LOAD_ADD_I16	= 273,
	PPC_ATOMIC_LOAD_ADD_I32	= 274,
	PPC_ATOMIC_LOAD_ADD_I64	= 275,
	PPC_ATOMIC_LOAD_ADD_I8	= 276,
	PPC_ATOMIC_LOAD_AND_I16	= 277,
	PPC_ATOMIC_LOAD_AND_I32	= 278,
	PPC_ATOMIC_LOAD_AND_I64	= 279,
	PPC_ATOMIC_LOAD_AND_I8	= 280,
	PPC_ATOMIC_LOAD_MAX_I16	= 281,
	PPC_ATOMIC_LOAD_MAX_I32	= 282,
	PPC_ATOMIC_LOAD_MAX_I64	= 283,
	PPC_ATOMIC_LOAD_MAX_I8	= 284,
	PPC_ATOMIC_LOAD_MIN_I16	= 285,
	PPC_ATOMIC_LOAD_MIN_I32	= 286,
	PPC_ATOMIC_LOAD_MIN_I64	= 287,
	PPC_ATOMIC_LOAD_MIN_I8	= 288,
	PPC_ATOMIC_LOAD_NAND_I16	= 289,
	PPC_ATOMIC_LOAD_NAND_I32	= 290,
	PPC_ATOMIC_LOAD_NAND_I64	= 291,
	PPC_ATOMIC_LOAD_NAND_I8	= 292,
	PPC_ATOMIC_LOAD_OR_I16	= 293,
	PPC_ATOMIC_LOAD_OR_I32	= 294,
	PPC_ATOMIC_LOAD_OR_I64	= 295,
	PPC_ATOMIC_LOAD_OR_I8	= 296,
	PPC_ATOMIC_LOAD_SUB_I16	= 297,
	PPC_ATOMIC_LOAD_SUB_I32	= 298,
	PPC_ATOMIC_LOAD_SUB_I64	= 299,
	PPC_ATOMIC_LOAD_SUB_I8	= 300,
	PPC_ATOMIC_LOAD_UMAX_I16	= 301,
	PPC_ATOMIC_LOAD_UMAX_I32	= 302,
	PPC_ATOMIC_LOAD_UMAX_I64	= 303,
	PPC_ATOMIC_LOAD_UMAX_I8	= 304,
	PPC_ATOMIC_LOAD_UMIN_I16	= 305,
	PPC_ATOMIC_LOAD_UMIN_I32	= 306,
	PPC_ATOMIC_LOAD_UMIN_I64	= 307,
	PPC_ATOMIC_LOAD_UMIN_I8	= 308,
	PPC_ATOMIC_LOAD_XOR_I16	= 309,
	PPC_ATOMIC_LOAD_XOR_I32	= 310,
	PPC_ATOMIC_LOAD_XOR_I64	= 311,
	PPC_ATOMIC_LOAD_XOR_I8	= 312,
	PPC_ATOMIC_SWAP_I16	= 313,
	PPC_ATOMIC_SWAP_I32	= 314,
	PPC_ATOMIC_SWAP_I64	= 315,
	PPC_ATOMIC_SWAP_I8	= 316,
	PPC_ATTN	= 317,
	PPC_B	= 318,
	PPC_BA	= 319,
	PPC_BC	= 320,
	PPC_BCC	= 321,
	PPC_BCCA	= 322,
	PPC_BCCCTR	= 323,
	PPC_BCCCTR8	= 324,
	PPC_BCCCTRL	= 325,
	PPC_BCCCTRL8	= 326,
	PPC_BCCL	= 327,
	PPC_BCCLA	= 328,
	PPC_BCCLR	= 329,
	PPC_BCCLRL	= 330,
	PPC_BCCTR	= 331,
	PPC_BCCTR8	= 332,
	PPC_BCCTR8n	= 333,
	PPC_BCCTRL	= 334,
	PPC_BCCTRL8	= 335,
	PPC_BCCTRL8n	= 336,
	PPC_BCCTRLn	= 337,
	PPC_BCCTRn	= 338,
	PPC_BCDCFNo	= 339,
	PPC_BCDCFSQo	= 340,
	PPC_BCDCFZo	= 341,
	PPC_BCDCPSGNo	= 342,
	PPC_BCDCTNo	= 343,
	PPC_BCDCTSQo	= 344,
	PPC_BCDCTZo	= 345,
	PPC_BCDSETSGNo	= 346,
	PPC_BCDSRo	= 347,
	PPC_BCDSo	= 348,
	PPC_BCDTRUNCo	= 349,
	PPC_BCDUSo	= 350,
	PPC_BCDUTRUNCo	= 351,
	PPC_BCL	= 352,
	PPC_BCLR	= 353,
	PPC_BCLRL	= 354,
	PPC_BCLRLn	= 355,
	PPC_BCLRn	= 356,
	PPC_BCLalways	= 357,
	PPC_BCLn	= 358,
	PPC_BCTR	= 359,
	PPC_BCTR8	= 360,
	PPC_BCTRL	= 361,
	PPC_BCTRL8	= 362,
	PPC_BCTRL8_LDinto_toc	= 363,
	PPC_BCn	= 364,
	PPC_BDNZ	= 365,
	PPC_BDNZ8	= 366,
	PPC_BDNZA	= 367,
	PPC_BDNZAm	= 368,
	PPC_BDNZAp	= 369,
	PPC_BDNZL	= 370,
	PPC_BDNZLA	= 371,
	PPC_BDNZLAm	= 372,
	PPC_BDNZLAp	= 373,
	PPC_BDNZLR	= 374,
	PPC_BDNZLR8	= 375,
	PPC_BDNZLRL	= 376,
	PPC_BDNZLRLm	= 377,
	PPC_BDNZLRLp	= 378,
	PPC_BDNZLRm	= 379,
	PPC_BDNZLRp	= 380,
	PPC_BDNZLm	= 381,
	PPC_BDNZLp	= 382,
	PPC_BDNZm	= 383,
	PPC_BDNZp	= 384,
	PPC_BDZ	= 385,
	PPC_BDZ8	= 386,
	PPC_BDZA	= 387,
	PPC_BDZAm	= 388,
	PPC_BDZAp	= 389,
	PPC_BDZL	= 390,
	PPC_BDZLA	= 391,
	PPC_BDZLAm	= 392,
	PPC_BDZLAp	= 393,
	PPC_BDZLR	= 394,
	PPC_BDZLR8	= 395,
	PPC_BDZLRL	= 396,
	PPC_BDZLRLm	= 397,
	PPC_BDZLRLp	= 398,
	PPC_BDZLRm	= 399,
	PPC_BDZLRp	= 400,
	PPC_BDZLm	= 401,
	PPC_BDZLp	= 402,
	PPC_BDZm	= 403,
	PPC_BDZp	= 404,
	PPC_BL	= 405,
	PPC_BL8	= 406,
	PPC_BL8_NOP	= 407,
	PPC_BL8_NOP_TLS	= 408,
	PPC_BL8_TLS	= 409,
	PPC_BL8_TLS_	= 410,
	PPC_BLA	= 411,
	PPC_BLA8	= 412,
	PPC_BLA8_NOP	= 413,
	PPC_BLR	= 414,
	PPC_BLR8	= 415,
	PPC_BLRL	= 416,
	PPC_BL_TLS	= 417,
	PPC_BPERMD	= 418,
	PPC_BRINC	= 419,
	PPC_CLRBHRB	= 420,
	PPC_CMPB	= 421,
	PPC_CMPB8	= 422,
	PPC_CMPD	= 423,
	PPC_CMPDI	= 424,
	PPC_CMPEQB	= 425,
	PPC_CMPLD	= 426,
	PPC_CMPLDI	= 427,
	PPC_CMPLW	= 428,
	PPC_CMPLWI	= 429,
	PPC_CMPRB	= 430,
	PPC_CMPRB8	= 431,
	PPC_CMPW	= 432,
	PPC_CMPWI	= 433,
	PPC_CNTLZD	= 434,
	PPC_CNTLZDo	= 435,
	PPC_CNTLZW	= 436,
	PPC_CNTLZW8	= 437,
	PPC_CNTLZW8o	= 438,
	PPC_CNTLZWo	= 439,
	PPC_CNTTZD	= 440,
	PPC_CNTTZDo	= 441,
	PPC_CNTTZW	= 442,
	PPC_CNTTZW8	= 443,
	PPC_CNTTZW8o	= 444,
	PPC_CNTTZWo	= 445,
	PPC_CP_ABORT	= 446,
	PPC_CP_COPY	= 447,
	PPC_CP_COPY8	= 448,
	PPC_CP_PASTE	= 449,
	PPC_CP_PASTE8	= 450,
	PPC_CP_PASTE8o	= 451,
	PPC_CP_PASTEo	= 452,
	PPC_CR6SET	= 453,
	PPC_CR6UNSET	= 454,
	PPC_CRAND	= 455,
	PPC_CRANDC	= 456,
	PPC_CREQV	= 457,
	PPC_CRNAND	= 458,
	PPC_CRNOR	= 459,
	PPC_CROR	= 460,
	PPC_CRORC	= 461,
	PPC_CRSET	= 462,
	PPC_CRUNSET	= 463,
	PPC_CRXOR	= 464,
	PPC_CTRL_DEP	= 465,
	PPC_DARN	= 466,
	PPC_DCBA	= 467,
	PPC_DCBF	= 468,
	PPC_DCBFEP	= 469,
	PPC_DCBI	= 470,
	PPC_DCBST	= 471,
	PPC_DCBSTEP	= 472,
	PPC_DCBT	= 473,
	PPC_DCBTEP	= 474,
	PPC_DCBTST	= 475,
	PPC_DCBTSTEP	= 476,
	PPC_DCBZ	= 477,
	PPC_DCBZEP	= 478,
	PPC_DCBZL	= 479,
	PPC_DCBZLEP	= 480,
	PPC_DCCCI	= 481,
	PPC_DIVD	= 482,
	PPC_DIVDE	= 483,
	PPC_DIVDEU	= 484,
	PPC_DIVDEUo	= 485,
	PPC_DIVDEo	= 486,
	PPC_DIVDU	= 487,
	PPC_DIVDUo	= 488,
	PPC_DIVDo	= 489,
	PPC_DIVW	= 490,
	PPC_DIVWE	= 491,
	PPC_DIVWEU	= 492,
	PPC_DIVWEUo	= 493,
	PPC_DIVWEo	= 494,
	PPC_DIVWU	= 495,
	PPC_DIVWUo	= 496,
	PPC_DIVWo	= 497,
	PPC_DSS	= 498,
	PPC_DSSALL	= 499,
	PPC_DST	= 500,
	PPC_DST64	= 501,
	PPC_DSTST	= 502,
	PPC_DSTST64	= 503,
	PPC_DSTSTT	= 504,
	PPC_DSTSTT64	= 505,
	PPC_DSTT	= 506,
	PPC_DSTT64	= 507,
	PPC_DYNALLOC	= 508,
	PPC_DYNALLOC8	= 509,
	PPC_DYNAREAOFFSET	= 510,
	PPC_DYNAREAOFFSET8	= 511,
	PPC_EFDABS	= 512,
	PPC_EFDADD	= 513,
	PPC_EFDCFS	= 514,
	PPC_EFDCFSF	= 515,
	PPC_EFDCFSI	= 516,
	PPC_EFDCFSID	= 517,
	PPC_EFDCFUF	= 518,
	PPC_EFDCFUI	= 519,
	PPC_EFDCFUID	= 520,
	PPC_EFDCMPEQ	= 521,
	PPC_EFDCMPGT	= 522,
	PPC_EFDCMPLT	= 523,
	PPC_EFDCTSF	= 524,
	PPC_EFDCTSI	= 525,
	PPC_EFDCTSIDZ	= 526,
	PPC_EFDCTSIZ	= 527,
	PPC_EFDCTUF	= 528,
	PPC_EFDCTUI	= 529,
	PPC_EFDCTUIDZ	= 530,
	PPC_EFDCTUIZ	= 531,
	PPC_EFDDIV	= 532,
	PPC_EFDMUL	= 533,
	PPC_EFDNABS	= 534,
	PPC_EFDNEG	= 535,
	PPC_EFDSUB	= 536,
	PPC_EFDTSTEQ	= 537,
	PPC_EFDTSTGT	= 538,
	PPC_EFDTSTLT	= 539,
	PPC_EFSABS	= 540,
	PPC_EFSADD	= 541,
	PPC_EFSCFD	= 542,
	PPC_EFSCFSF	= 543,
	PPC_EFSCFSI	= 544,
	PPC_EFSCFUF	= 545,
	PPC_EFSCFUI	= 546,
	PPC_EFSCMPEQ	= 547,
	PPC_EFSCMPGT	= 548,
	PPC_EFSCMPLT	= 549,
	PPC_EFSCTSF	= 550,
	PPC_EFSCTSI	= 551,
	PPC_EFSCTSIZ	= 552,
	PPC_EFSCTUF	= 553,
	PPC_EFSCTUI	= 554,
	PPC_EFSCTUIZ	= 555,
	PPC_EFSDIV	= 556,
	PPC_EFSMUL	= 557,
	PPC_EFSNABS	= 558,
	PPC_EFSNEG	= 559,
	PPC_EFSSUB	= 560,
	PPC_EFSTSTEQ	= 561,
	PPC_EFSTSTGT	= 562,
	PPC_EFSTSTLT	= 563,
	PPC_EH_SjLj_LongJmp32	= 564,
	PPC_EH_SjLj_LongJmp64	= 565,
	PPC_EH_SjLj_SetJmp32	= 566,
	PPC_EH_SjLj_SetJmp64	= 567,
	PPC_EH_SjLj_Setup	= 568,
	PPC_EQV	= 569,
	PPC_EQV8	= 570,
	PPC_EQV8o	= 571,
	PPC_EQVo	= 572,
	PPC_EVABS	= 573,
	PPC_EVADDIW	= 574,
	PPC_EVADDSMIAAW	= 575,
	PPC_EVADDSSIAAW	= 576,
	PPC_EVADDUMIAAW	= 577,
	PPC_EVADDUSIAAW	= 578,
	PPC_EVADDW	= 579,
	PPC_EVAND	= 580,
	PPC_EVANDC	= 581,
	PPC_EVCMPEQ	= 582,
	PPC_EVCMPGTS	= 583,
	PPC_EVCMPGTU	= 584,
	PPC_EVCMPLTS	= 585,
	PPC_EVCMPLTU	= 586,
	PPC_EVCNTLSW	= 587,
	PPC_EVCNTLZW	= 588,
	PPC_EVDIVWS	= 589,
	PPC_EVDIVWU	= 590,
	PPC_EVEQV	= 591,
	PPC_EVEXTSB	= 592,
	PPC_EVEXTSH	= 593,
	PPC_EVFSABS	= 594,
	PPC_EVFSADD	= 595,
	PPC_EVFSCFSF	= 596,
	PPC_EVFSCFSI	= 597,
	PPC_EVFSCFUF	= 598,
	PPC_EVFSCFUI	= 599,
	PPC_EVFSCMPEQ	= 600,
	PPC_EVFSCMPGT	= 601,
	PPC_EVFSCMPLT	= 602,
	PPC_EVFSCTSF	= 603,
	PPC_EVFSCTSI	= 604,
	PPC_EVFSCTSIZ	= 605,
	PPC_EVFSCTUF	= 606,
	PPC_EVFSCTUI	= 607,
	PPC_EVFSCTUIZ	= 608,
	PPC_EVFSDIV	= 609,
	PPC_EVFSMUL	= 610,
	PPC_EVFSNABS	= 611,
	PPC_EVFSNEG	= 612,
	PPC_EVFSSUB	= 613,
	PPC_EVFSTSTEQ	= 614,
	PPC_EVFSTSTGT	= 615,
	PPC_EVFSTSTLT	= 616,
	PPC_EVLDD	= 617,
	PPC_EVLDDX	= 618,
	PPC_EVLDH	= 619,
	PPC_EVLDHX	= 620,
	PPC_EVLDW	= 621,
	PPC_EVLDWX	= 622,
	PPC_EVLHHESPLAT	= 623,
	PPC_EVLHHESPLATX	= 624,
	PPC_EVLHHOSSPLAT	= 625,
	PPC_EVLHHOSSPLATX	= 626,
	PPC_EVLHHOUSPLAT	= 627,
	PPC_EVLHHOUSPLATX	= 628,
	PPC_EVLWHE	= 629,
	PPC_EVLWHEX	= 630,
	PPC_EVLWHOS	= 631,
	PPC_EVLWHOSX	= 632,
	PPC_EVLWHOU	= 633,
	PPC_EVLWHOUX	= 634,
	PPC_EVLWHSPLAT	= 635,
	PPC_EVLWHSPLATX	= 636,
	PPC_EVLWWSPLAT	= 637,
	PPC_EVLWWSPLATX	= 638,
	PPC_EVMERGEHI	= 639,
	PPC_EVMERGEHILO	= 640,
	PPC_EVMERGELO	= 641,
	PPC_EVMERGELOHI	= 642,
	PPC_EVMHEGSMFAA	= 643,
	PPC_EVMHEGSMFAN	= 644,
	PPC_EVMHEGSMIAA	= 645,
	PPC_EVMHEGSMIAN	= 646,
	PPC_EVMHEGUMIAA	= 647,
	PPC_EVMHEGUMIAN	= 648,
	PPC_EVMHESMF	= 649,
	PPC_EVMHESMFA	= 650,
	PPC_EVMHESMFAAW	= 651,
	PPC_EVMHESMFANW	= 652,
	PPC_EVMHESMI	= 653,
	PPC_EVMHESMIA	= 654,
	PPC_EVMHESMIAAW	= 655,
	PPC_EVMHESMIANW	= 656,
	PPC_EVMHESSF	= 657,
	PPC_EVMHESSFA	= 658,
	PPC_EVMHESSFAAW	= 659,
	PPC_EVMHESSFANW	= 660,
	PPC_EVMHESSIAAW	= 661,
	PPC_EVMHESSIANW	= 662,
	PPC_EVMHEUMI	= 663,
	PPC_EVMHEUMIA	= 664,
	PPC_EVMHEUMIAAW	= 665,
	PPC_EVMHEUMIANW	= 666,
	PPC_EVMHEUSIAAW	= 667,
	PPC_EVMHEUSIANW	= 668,
	PPC_EVMHOGSMFAA	= 669,
	PPC_EVMHOGSMFAN	= 670,
	PPC_EVMHOGSMIAA	= 671,
	PPC_EVMHOGSMIAN	= 672,
	PPC_EVMHOGUMIAA	= 673,
	PPC_EVMHOGUMIAN	= 674,
	PPC_EVMHOSMF	= 675,
	PPC_EVMHOSMFA	= 676,
	PPC_EVMHOSMFAAW	= 677,
	PPC_EVMHOSMFANW	= 678,
	PPC_EVMHOSMI	= 679,
	PPC_EVMHOSMIA	= 680,
	PPC_EVMHOSMIAAW	= 681,
	PPC_EVMHOSMIANW	= 682,
	PPC_EVMHOSSF	= 683,
	PPC_EVMHOSSFA	= 684,
	PPC_EVMHOSSFAAW	= 685,
	PPC_EVMHOSSFANW	= 686,
	PPC_EVMHOSSIAAW	= 687,
	PPC_EVMHOSSIANW	= 688,
	PPC_EVMHOUMI	= 689,
	PPC_EVMHOUMIA	= 690,
	PPC_EVMHOUMIAAW	= 691,
	PPC_EVMHOUMIANW	= 692,
	PPC_EVMHOUSIAAW	= 693,
	PPC_EVMHOUSIANW	= 694,
	PPC_EVMRA	= 695,
	PPC_EVMWHSMF	= 696,
	PPC_EVMWHSMFA	= 697,
	PPC_EVMWHSMI	= 698,
	PPC_EVMWHSMIA	= 699,
	PPC_EVMWHSSF	= 700,
	PPC_EVMWHSSFA	= 701,
	PPC_EVMWHUMI	= 702,
	PPC_EVMWHUMIA	= 703,
	PPC_EVMWLSMIAAW	= 704,
	PPC_EVMWLSMIANW	= 705,
	PPC_EVMWLSSIAAW	= 706,
	PPC_EVMWLSSIANW	= 707,
	PPC_EVMWLUMI	= 708,
	PPC_EVMWLUMIA	= 709,
	PPC_EVMWLUMIAAW	= 710,
	PPC_EVMWLUMIANW	= 711,
	PPC_EVMWLUSIAAW	= 712,
	PPC_EVMWLUSIANW	= 713,
	PPC_EVMWSMF	= 714,
	PPC_EVMWSMFA	= 715,
	PPC_EVMWSMFAA	= 716,
	PPC_EVMWSMFAN	= 717,
	PPC_EVMWSMI	= 718,
	PPC_EVMWSMIA	= 719,
	PPC_EVMWSMIAA	= 720,
	PPC_EVMWSMIAN	= 721,
	PPC_EVMWSSF	= 722,
	PPC_EVMWSSFA	= 723,
	PPC_EVMWSSFAA	= 724,
	PPC_EVMWSSFAN	= 725,
	PPC_EVMWUMI	= 726,
	PPC_EVMWUMIA	= 727,
	PPC_EVMWUMIAA	= 728,
	PPC_EVMWUMIAN	= 729,
	PPC_EVNAND	= 730,
	PPC_EVNEG	= 731,
	PPC_EVNOR	= 732,
	PPC_EVOR	= 733,
	PPC_EVORC	= 734,
	PPC_EVRLW	= 735,
	PPC_EVRLWI	= 736,
	PPC_EVRNDW	= 737,
	PPC_EVSEL	= 738,
	PPC_EVSLW	= 739,
	PPC_EVSLWI	= 740,
	PPC_EVSPLATFI	= 741,
	PPC_EVSPLATI	= 742,
	PPC_EVSRWIS	= 743,
	PPC_EVSRWIU	= 744,
	PPC_EVSRWS	= 745,
	PPC_EVSRWU	= 746,
	PPC_EVSTDD	= 747,
	PPC_EVSTDDX	= 748,
	PPC_EVSTDH	= 749,
	PPC_EVSTDHX	= 750,
	PPC_EVSTDW	= 751,
	PPC_EVSTDWX	= 752,
	PPC_EVSTWHE	= 753,
	PPC_EVSTWHEX	= 754,
	PPC_EVSTWHO	= 755,
	PPC_EVSTWHOX	= 756,
	PPC_EVSTWWE	= 757,
	PPC_EVSTWWEX	= 758,
	PPC_EVSTWWO	= 759,
	PPC_EVSTWWOX	= 760,
	PPC_EVSUBFSMIAAW	= 761,
	PPC_EVSUBFSSIAAW	= 762,
	PPC_EVSUBFUMIAAW	= 763,
	PPC_EVSUBFUSIAAW	= 764,
	PPC_EVSUBFW	= 765,
	PPC_EVSUBIFW	= 766,
	PPC_EVXOR	= 767,
	PPC_EXTSB	= 768,
	PPC_EXTSB8	= 769,
	PPC_EXTSB8_32_64	= 770,
	PPC_EXTSB8o	= 771,
	PPC_EXTSBo	= 772,
	PPC_EXTSH	= 773,
	PPC_EXTSH8	= 774,
	PPC_EXTSH8_32_64	= 775,
	PPC_EXTSH8o	= 776,
	PPC_EXTSHo	= 777,
	PPC_EXTSW	= 778,
	PPC_EXTSWSLI	= 779,
	PPC_EXTSWSLIo	= 780,
	PPC_EXTSW_32	= 781,
	PPC_EXTSW_32_64	= 782,
	PPC_EXTSW_32_64o	= 783,
	PPC_EXTSWo	= 784,
	PPC_EnforceIEIO	= 785,
	PPC_FABSD	= 786,
	PPC_FABSDo	= 787,
	PPC_FABSS	= 788,
	PPC_FABSSo	= 789,
	PPC_FADD	= 790,
	PPC_FADDS	= 791,
	PPC_FADDSo	= 792,
	PPC_FADDo	= 793,
	PPC_FADDrtz	= 794,
	PPC_FCFID	= 795,
	PPC_FCFIDS	= 796,
	PPC_FCFIDSo	= 797,
	PPC_FCFIDU	= 798,
	PPC_FCFIDUS	= 799,
	PPC_FCFIDUSo	= 800,
	PPC_FCFIDUo	= 801,
	PPC_FCFIDo	= 802,
	PPC_FCMPUD	= 803,
	PPC_FCMPUS	= 804,
	PPC_FCPSGND	= 805,
	PPC_FCPSGNDo	= 806,
	PPC_FCPSGNS	= 807,
	PPC_FCPSGNSo	= 808,
	PPC_FCTID	= 809,
	PPC_FCTIDU	= 810,
	PPC_FCTIDUZ	= 811,
	PPC_FCTIDUZo	= 812,
	PPC_FCTIDUo	= 813,
	PPC_FCTIDZ	= 814,
	PPC_FCTIDZo	= 815,
	PPC_FCTIDo	= 816,
	PPC_FCTIW	= 817,
	PPC_FCTIWU	= 818,
	PPC_FCTIWUZ	= 819,
	PPC_FCTIWUZo	= 820,
	PPC_FCTIWUo	= 821,
	PPC_FCTIWZ	= 822,
	PPC_FCTIWZo	= 823,
	PPC_FCTIWo	= 824,
	PPC_FDIV	= 825,
	PPC_FDIVS	= 826,
	PPC_FDIVSo	= 827,
	PPC_FDIVo	= 828,
	PPC_FMADD	= 829,
	PPC_FMADDS	= 830,
	PPC_FMADDSo	= 831,
	PPC_FMADDo	= 832,
	PPC_FMR	= 833,
	PPC_FMRo	= 834,
	PPC_FMSUB	= 835,
	PPC_FMSUBS	= 836,
	PPC_FMSUBSo	= 837,
	PPC_FMSUBo	= 838,
	PPC_FMUL	= 839,
	PPC_FMULS	= 840,
	PPC_FMULSo	= 841,
	PPC_FMULo	= 842,
	PPC_FNABSD	= 843,
	PPC_FNABSDo	= 844,
	PPC_FNABSS	= 845,
	PPC_FNABSSo	= 846,
	PPC_FNEGD	= 847,
	PPC_FNEGDo	= 848,
	PPC_FNEGS	= 849,
	PPC_FNEGSo	= 850,
	PPC_FNMADD	= 851,
	PPC_FNMADDS	= 852,
	PPC_FNMADDSo	= 853,
	PPC_FNMADDo	= 854,
	PPC_FNMSUB	= 855,
	PPC_FNMSUBS	= 856,
	PPC_FNMSUBSo	= 857,
	PPC_FNMSUBo	= 858,
	PPC_FRE	= 859,
	PPC_FRES	= 860,
	PPC_FRESo	= 861,
	PPC_FREo	= 862,
	PPC_FRIMD	= 863,
	PPC_FRIMDo	= 864,
	PPC_FRIMS	= 865,
	PPC_FRIMSo	= 866,
	PPC_FRIND	= 867,
	PPC_FRINDo	= 868,
	PPC_FRINS	= 869,
	PPC_FRINSo	= 870,
	PPC_FRIPD	= 871,
	PPC_FRIPDo	= 872,
	PPC_FRIPS	= 873,
	PPC_FRIPSo	= 874,
	PPC_FRIZD	= 875,
	PPC_FRIZDo	= 876,
	PPC_FRIZS	= 877,
	PPC_FRIZSo	= 878,
	PPC_FRSP	= 879,
	PPC_FRSPo	= 880,
	PPC_FRSQRTE	= 881,
	PPC_FRSQRTES	= 882,
	PPC_FRSQRTESo	= 883,
	PPC_FRSQRTEo	= 884,
	PPC_FSELD	= 885,
	PPC_FSELDo	= 886,
	PPC_FSELS	= 887,
	PPC_FSELSo	= 888,
	PPC_FSQRT	= 889,
	PPC_FSQRTS	= 890,
	PPC_FSQRTSo	= 891,
	PPC_FSQRTo	= 892,
	PPC_FSUB	= 893,
	PPC_FSUBS	= 894,
	PPC_FSUBSo	= 895,
	PPC_FSUBo	= 896,
	PPC_FTDIV	= 897,
	PPC_FTSQRT	= 898,
	PPC_GETtlsADDR	= 899,
	PPC_GETtlsADDR32	= 900,
	PPC_GETtlsldADDR	= 901,
	PPC_GETtlsldADDR32	= 902,
	PPC_HRFID	= 903,
	PPC_ICBI	= 904,
	PPC_ICBIEP	= 905,
	PPC_ICBLC	= 906,
	PPC_ICBLQ	= 907,
	PPC_ICBT	= 908,
	PPC_ICBTLS	= 909,
	PPC_ICCCI	= 910,
	PPC_ISEL	= 911,
	PPC_ISEL8	= 912,
	PPC_ISYNC	= 913,
	PPC_LA	= 914,
	PPC_LBARX	= 915,
	PPC_LBARXL	= 916,
	PPC_LBEPX	= 917,
	PPC_LBZ	= 918,
	PPC_LBZ8	= 919,
	PPC_LBZCIX	= 920,
	PPC_LBZU	= 921,
	PPC_LBZU8	= 922,
	PPC_LBZUX	= 923,
	PPC_LBZUX8	= 924,
	PPC_LBZX	= 925,
	PPC_LBZX8	= 926,
	PPC_LBZXTLS	= 927,
	PPC_LBZXTLS_	= 928,
	PPC_LBZXTLS_32	= 929,
	PPC_LD	= 930,
	PPC_LDARX	= 931,
	PPC_LDARXL	= 932,
	PPC_LDAT	= 933,
	PPC_LDBRX	= 934,
	PPC_LDCIX	= 935,
	PPC_LDMX	= 936,
	PPC_LDU	= 937,
	PPC_LDUX	= 938,
	PPC_LDX	= 939,
	PPC_LDXTLS	= 940,
	PPC_LDXTLS_	= 941,
	PPC_LDgotTprelL	= 942,
	PPC_LDgotTprelL32	= 943,
	PPC_LDtoc	= 944,
	PPC_LDtocBA	= 945,
	PPC_LDtocCPT	= 946,
	PPC_LDtocJTI	= 947,
	PPC_LDtocL	= 948,
	PPC_LFD	= 949,
	PPC_LFDEPX	= 950,
	PPC_LFDU	= 951,
	PPC_LFDUX	= 952,
	PPC_LFDX	= 953,
	PPC_LFIWAX	= 954,
	PPC_LFIWZX	= 955,
	PPC_LFS	= 956,
	PPC_LFSU	= 957,
	PPC_LFSUX	= 958,
	PPC_LFSX	= 959,
	PPC_LHA	= 960,
	PPC_LHA8	= 961,
	PPC_LHARX	= 962,
	PPC_LHARXL	= 963,
	PPC_LHAU	= 964,
	PPC_LHAU8	= 965,
	PPC_LHAUX	= 966,
	PPC_LHAUX8	= 967,
	PPC_LHAX	= 968,
	PPC_LHAX8	= 969,
	PPC_LHBRX	= 970,
	PPC_LHBRX8	= 971,
	PPC_LHEPX	= 972,
	PPC_LHZ	= 973,
	PPC_LHZ8	= 974,
	PPC_LHZCIX	= 975,
	PPC_LHZU	= 976,
	PPC_LHZU8	= 977,
	PPC_LHZUX	= 978,
	PPC_LHZUX8	= 979,
	PPC_LHZX	= 980,
	PPC_LHZX8	= 981,
	PPC_LHZXTLS	= 982,
	PPC_LHZXTLS_	= 983,
	PPC_LHZXTLS_32	= 984,
	PPC_LI	= 985,
	PPC_LI8	= 986,
	PPC_LIS	= 987,
	PPC_LIS8	= 988,
	PPC_LMW	= 989,
	PPC_LSWI	= 990,
	PPC_LVEBX	= 991,
	PPC_LVEHX	= 992,
	PPC_LVEWX	= 993,
	PPC_LVSL	= 994,
	PPC_LVSR	= 995,
	PPC_LVX	= 996,
	PPC_LVXL	= 997,
	PPC_LWA	= 998,
	PPC_LWARX	= 999,
	PPC_LWARXL	= 1000,
	PPC_LWAT	= 1001,
	PPC_LWAUX	= 1002,
	PPC_LWAX	= 1003,
	PPC_LWAX_32	= 1004,
	PPC_LWA_32	= 1005,
	PPC_LWBRX	= 1006,
	PPC_LWBRX8	= 1007,
	PPC_LWEPX	= 1008,
	PPC_LWZ	= 1009,
	PPC_LWZ8	= 1010,
	PPC_LWZCIX	= 1011,
	PPC_LWZU	= 1012,
	PPC_LWZU8	= 1013,
	PPC_LWZUX	= 1014,
	PPC_LWZUX8	= 1015,
	PPC_LWZX	= 1016,
	PPC_LWZX8	= 1017,
	PPC_LWZXTLS	= 1018,
	PPC_LWZXTLS_	= 1019,
	PPC_LWZXTLS_32	= 1020,
	PPC_LWZtoc	= 1021,
	PPC_LXSD	= 1022,
	PPC_LXSDX	= 1023,
	PPC_LXSIBZX	= 1024,
	PPC_LXSIHZX	= 1025,
	PPC_LXSIWAX	= 1026,
	PPC_LXSIWZX	= 1027,
	PPC_LXSSP	= 1028,
	PPC_LXSSPX	= 1029,
	PPC_LXV	= 1030,
	PPC_LXVB16X	= 1031,
	PPC_LXVD2X	= 1032,
	PPC_LXVDSX	= 1033,
	PPC_LXVH8X	= 1034,
	PPC_LXVL	= 1035,
	PPC_LXVLL	= 1036,
	PPC_LXVW4X	= 1037,
	PPC_LXVWSX	= 1038,
	PPC_LXVX	= 1039,
	PPC_MADDHD	= 1040,
	PPC_MADDHDU	= 1041,
	PPC_MADDLD	= 1042,
	PPC_MBAR	= 1043,
	PPC_MCRF	= 1044,
	PPC_MCRFS	= 1045,
	PPC_MCRXRX	= 1046,
	PPC_MFBHRBE	= 1047,
	PPC_MFCR	= 1048,
	PPC_MFCR8	= 1049,
	PPC_MFCTR	= 1050,
	PPC_MFCTR8	= 1051,
	PPC_MFDCR	= 1052,
	PPC_MFFS	= 1053,
	PPC_MFFSCDRN	= 1054,
	PPC_MFFSCDRNI	= 1055,
	PPC_MFFSCE	= 1056,
	PPC_MFFSCRN	= 1057,
	PPC_MFFSCRNI	= 1058,
	PPC_MFFSL	= 1059,
	PPC_MFFSo	= 1060,
	PPC_MFLR	= 1061,
	PPC_MFLR8	= 1062,
	PPC_MFMSR	= 1063,
	PPC_MFOCRF	= 1064,
	PPC_MFOCRF8	= 1065,
	PPC_MFPMR	= 1066,
	PPC_MFSPR	= 1067,
	PPC_MFSPR8	= 1068,
	PPC_MFSR	= 1069,
	PPC_MFSRIN	= 1070,
	PPC_MFTB	= 1071,
	PPC_MFTB8	= 1072,
	PPC_MFVRD	= 1073,
	PPC_MFVRSAVE	= 1074,
	PPC_MFVRSAVEv	= 1075,
	PPC_MFVSCR	= 1076,
	PPC_MFVSRD	= 1077,
	PPC_MFVSRLD	= 1078,
	PPC_MFVSRWZ	= 1079,
	PPC_MODSD	= 1080,
	PPC_MODSW	= 1081,
	PPC_MODUD	= 1082,
	PPC_MODUW	= 1083,
	PPC_MSGSYNC	= 1084,
	PPC_MSYNC	= 1085,
	PPC_MTCRF	= 1086,
	PPC_MTCRF8	= 1087,
	PPC_MTCTR	= 1088,
	PPC_MTCTR8	= 1089,
	PPC_MTCTR8loop	= 1090,
	PPC_MTCTRloop	= 1091,
	PPC_MTDCR	= 1092,
	PPC_MTFSB0	= 1093,
	PPC_MTFSB1	= 1094,
	PPC_MTFSF	= 1095,
	PPC_MTFSFI	= 1096,
	PPC_MTFSFIo	= 1097,
	PPC_MTFSFb	= 1098,
	PPC_MTFSFo	= 1099,
	PPC_MTLR	= 1100,
	PPC_MTLR8	= 1101,
	PPC_MTMSR	= 1102,
	PPC_MTMSRD	= 1103,
	PPC_MTOCRF	= 1104,
	PPC_MTOCRF8	= 1105,
	PPC_MTPMR	= 1106,
	PPC_MTSPR	= 1107,
	PPC_MTSPR8	= 1108,
	PPC_MTSR	= 1109,
	PPC_MTSRIN	= 1110,
	PPC_MTVRSAVE	= 1111,
	PPC_MTVRSAVEv	= 1112,
	PPC_MTVSCR	= 1113,
	PPC_MTVSRD	= 1114,
	PPC_MTVSRDD	= 1115,
	PPC_MTVSRWA	= 1116,
	PPC_MTVSRWS	= 1117,
	PPC_MTVSRWZ	= 1118,
	PPC_MULHD	= 1119,
	PPC_MULHDU	= 1120,
	PPC_MULHDUo	= 1121,
	PPC_MULHDo	= 1122,
	PPC_MULHW	= 1123,
	PPC_MULHWU	= 1124,
	PPC_MULHWUo	= 1125,
	PPC_MULHWo	= 1126,
	PPC_MULLD	= 1127,
	PPC_MULLDo	= 1128,
	PPC_MULLI	= 1129,
	PPC_MULLI8	= 1130,
	PPC_MULLW	= 1131,
	PPC_MULLWo	= 1132,
	PPC_MoveGOTtoLR	= 1133,
	PPC_MovePCtoLR	= 1134,
	PPC_MovePCtoLR8	= 1135,
	PPC_NAND	= 1136,
	PPC_NAND8	= 1137,
	PPC_NAND8o	= 1138,
	PPC_NANDo	= 1139,
	PPC_NAP	= 1140,
	PPC_NEG	= 1141,
	PPC_NEG8	= 1142,
	PPC_NEG8o	= 1143,
	PPC_NEGo	= 1144,
	PPC_NOP	= 1145,
	PPC_NOP_GT_PWR6	= 1146,
	PPC_NOP_GT_PWR7	= 1147,
	PPC_NOR	= 1148,
	PPC_NOR8	= 1149,
	PPC_NOR8o	= 1150,
	PPC_NORo	= 1151,
	PPC_OR	= 1152,
	PPC_OR8	= 1153,
	PPC_OR8o	= 1154,
	PPC_ORC	= 1155,
	PPC_ORC8	= 1156,
	PPC_ORC8o	= 1157,
	PPC_ORCo	= 1158,
	PPC_ORI	= 1159,
	PPC_ORI8	= 1160,
	PPC_ORIS	= 1161,
	PPC_ORIS8	= 1162,
	PPC_ORo	= 1163,
	PPC_POPCNTB	= 1164,
	PPC_POPCNTD	= 1165,
	PPC_POPCNTW	= 1166,
	PPC_PPC32GOT	= 1167,
	PPC_PPC32PICGOT	= 1168,
	PPC_PSC_DCBZL	= 1169,
	PPC_PSQ_L	= 1170,
	PPC_PSQ_LU	= 1171,
	PPC_PSQ_LUX	= 1172,
	PPC_PSQ_LX	= 1173,
	PPC_PSQ_ST	= 1174,
	PPC_PSQ_STU	= 1175,
	PPC_PSQ_STUX	= 1176,
	PPC_PSQ_STX	= 1177,
	PPC_PS_ABS	= 1178,
	PPC_PS_ABSo	= 1179,
	PPC_PS_ADD	= 1180,
	PPC_PS_ADDo	= 1181,
	PPC_PS_CMPO0	= 1182,
	PPC_PS_CMPO1	= 1183,
	PPC_PS_CMPU0	= 1184,
	PPC_PS_CMPU1	= 1185,
	PPC_PS_DIV	= 1186,
	PPC_PS_DIVo	= 1187,
	PPC_PS_MADD	= 1188,
	PPC_PS_MADDS0	= 1189,
	PPC_PS_MADDS0o	= 1190,
	PPC_PS_MADDS1	= 1191,
	PPC_PS_MADDS1o	= 1192,
	PPC_PS_MADDo	= 1193,
	PPC_PS_MERGE00	= 1194,
	PPC_PS_MERGE00o	= 1195,
	PPC_PS_MERGE01	= 1196,
	PPC_PS_MERGE01o	= 1197,
	PPC_PS_MERGE10	= 1198,
	PPC_PS_MERGE10o	= 1199,
	PPC_PS_MERGE11	= 1200,
	PPC_PS_MERGE11o	= 1201,
	PPC_PS_MR	= 1202,
	PPC_PS_MRo	= 1203,
	PPC_PS_MSUB	= 1204,
	PPC_PS_MSUBo	= 1205,
	PPC_PS_MUL	= 1206,
	PPC_PS_MULS0	= 1207,
	PPC_PS_MULS0o	= 1208,
	PPC_PS_MULS1	= 1209,
	PPC_PS_MULS1o	= 1210,
	PPC_PS_MULo	= 1211,
	PPC_PS_NABS	= 1212,
	PPC_PS_NABSo	= 1213,
	PPC_PS_NEG	= 1214,
	PPC_PS_NEGo	= 1215,
	PPC_PS_NMADD	= 1216,
	PPC_PS_NMADDo	= 1217,
	PPC_PS_NMSUB	= 1218,
	PPC_PS_NMSUBo	= 1219,
	PPC_PS_RES	= 1220,
	PPC_PS_RESo	= 1221,
	PPC_PS_RSQRTE	= 1222,
	PPC_PS_RSQRTEo	= 1223,
	PPC_PS_SEL	= 1224,
	PPC_PS_SELo	= 1225,
	PPC_PS_SUB	= 1226,
	PPC_PS_SUBo	= 1227,
	PPC_PS_SUM0	= 1228,
	PPC_PS_SUM0o	= 1229,
	PPC_PS_SUM1	= 1230,
	PPC_PS_SUM1o	= 1231,
	PPC_QVALIGNI	= 1232,
	PPC_QVALIGNIb	= 1233,
	PPC_QVALIGNIs	= 1234,
	PPC_QVESPLATI	= 1235,
	PPC_QVESPLATIb	= 1236,
	PPC_QVESPLATIs	= 1237,
	PPC_QVFABS	= 1238,
	PPC_QVFABSs	= 1239,
	PPC_QVFADD	= 1240,
	PPC_QVFADDS	= 1241,
	PPC_QVFADDSs	= 1242,
	PPC_QVFCFID	= 1243,
	PPC_QVFCFIDS	= 1244,
	PPC_QVFCFIDU	= 1245,
	PPC_QVFCFIDUS	= 1246,
	PPC_QVFCFIDb	= 1247,
	PPC_QVFCMPEQ	= 1248,
	PPC_QVFCMPEQb	= 1249,
	PPC_QVFCMPEQbs	= 1250,
	PPC_QVFCMPGT	= 1251,
	PPC_QVFCMPGTb	= 1252,
	PPC_QVFCMPGTbs	= 1253,
	PPC_QVFCMPLT	= 1254,
	PPC_QVFCMPLTb	= 1255,
	PPC_QVFCMPLTbs	= 1256,
	PPC_QVFCPSGN	= 1257,
	PPC_QVFCPSGNs	= 1258,
	PPC_QVFCTID	= 1259,
	PPC_QVFCTIDU	= 1260,
	PPC_QVFCTIDUZ	= 1261,
	PPC_QVFCTIDZ	= 1262,
	PPC_QVFCTIDb	= 1263,
	PPC_QVFCTIW	= 1264,
	PPC_QVFCTIWU	= 1265,
	PPC_QVFCTIWUZ	= 1266,
	PPC_QVFCTIWZ	= 1267,
	PPC_QVFLOGICAL	= 1268,
	PPC_QVFLOGICALb	= 1269,
	PPC_QVFLOGICALs	= 1270,
	PPC_QVFMADD	= 1271,
	PPC_QVFMADDS	= 1272,
	PPC_QVFMADDSs	= 1273,
	PPC_QVFMR	= 1274,
	PPC_QVFMRb	= 1275,
	PPC_QVFMRs	= 1276,
	PPC_QVFMSUB	= 1277,
	PPC_QVFMSUBS	= 1278,
	PPC_QVFMSUBSs	= 1279,
	PPC_QVFMUL	= 1280,
	PPC_QVFMULS	= 1281,
	PPC_QVFMULSs	= 1282,
	PPC_QVFNABS	= 1283,
	PPC_QVFNABSs	= 1284,
	PPC_QVFNEG	= 1285,
	PPC_QVFNEGs	= 1286,
	PPC_QVFNMADD	= 1287,
	PPC_QVFNMADDS	= 1288,
	PPC_QVFNMADDSs	= 1289,
	PPC_QVFNMSUB	= 1290,
	PPC_QVFNMSUBS	= 1291,
	PPC_QVFNMSUBSs	= 1292,
	PPC_QVFPERM	= 1293,
	PPC_QVFPERMs	= 1294,
	PPC_QVFRE	= 1295,
	PPC_QVFRES	= 1296,
	PPC_QVFRESs	= 1297,
	PPC_QVFRIM	= 1298,
	PPC_QVFRIMs	= 1299,
	PPC_QVFRIN	= 1300,
	PPC_QVFRINs	= 1301,
	PPC_QVFRIP	= 1302,
	PPC_QVFRIPs	= 1303,
	PPC_QVFRIZ	= 1304,
	PPC_QVFRIZs	= 1305,
	PPC_QVFRSP	= 1306,
	PPC_QVFRSPs	= 1307,
	PPC_QVFRSQRTE	= 1308,
	PPC_QVFRSQRTES	= 1309,
	PPC_QVFRSQRTESs	= 1310,
	PPC_QVFSEL	= 1311,
	PPC_QVFSELb	= 1312,
	PPC_QVFSELbb	= 1313,
	PPC_QVFSELbs	= 1314,
	PPC_QVFSUB	= 1315,
	PPC_QVFSUBS	= 1316,
	PPC_QVFSUBSs	= 1317,
	PPC_QVFTSTNAN	= 1318,
	PPC_QVFTSTNANb	= 1319,
	PPC_QVFTSTNANbs	= 1320,
	PPC_QVFXMADD	= 1321,
	PPC_QVFXMADDS	= 1322,
	PPC_QVFXMUL	= 1323,
	PPC_QVFXMULS	= 1324,
	PPC_QVFXXCPNMADD	= 1325,
	PPC_QVFXXCPNMADDS	= 1326,
	PPC_QVFXXMADD	= 1327,
	PPC_QVFXXMADDS	= 1328,
	PPC_QVFXXNPMADD	= 1329,
	PPC_QVFXXNPMADDS	= 1330,
	PPC_QVGPCI	= 1331,
	PPC_QVLFCDUX	= 1332,
	PPC_QVLFCDUXA	= 1333,
	PPC_QVLFCDX	= 1334,
	PPC_QVLFCDXA	= 1335,
	PPC_QVLFCSUX	= 1336,
	PPC_QVLFCSUXA	= 1337,
	PPC_QVLFCSX	= 1338,
	PPC_QVLFCSXA	= 1339,
	PPC_QVLFCSXs	= 1340,
	PPC_QVLFDUX	= 1341,
	PPC_QVLFDUXA	= 1342,
	PPC_QVLFDX	= 1343,
	PPC_QVLFDXA	= 1344,
	PPC_QVLFDXb	= 1345,
	PPC_QVLFIWAX	= 1346,
	PPC_QVLFIWAXA	= 1347,
	PPC_QVLFIWZX	= 1348,
	PPC_QVLFIWZXA	= 1349,
	PPC_QVLFSUX	= 1350,
	PPC_QVLFSUXA	= 1351,
	PPC_QVLFSX	= 1352,
	PPC_QVLFSXA	= 1353,
	PPC_QVLFSXb	= 1354,
	PPC_QVLFSXs	= 1355,
	PPC_QVLPCLDX	= 1356,
	PPC_QVLPCLSX	= 1357,
	PPC_QVLPCLSXint	= 1358,
	PPC_QVLPCRDX	= 1359,
	PPC_QVLPCRSX	= 1360,
	PPC_QVSTFCDUX	= 1361,
	PPC_QVSTFCDUXA	= 1362,
	PPC_QVSTFCDUXI	= 1363,
	PPC_QVSTFCDUXIA	= 1364,
	PPC_QVSTFCDX	= 1365,
	PPC_QVSTFCDXA	= 1366,
	PPC_QVSTFCDXI	= 1367,
	PPC_QVSTFCDXIA	= 1368,
	PPC_QVSTFCSUX	= 1369,
	PPC_QVSTFCSUXA	= 1370,
	PPC_QVSTFCSUXI	= 1371,
	PPC_QVSTFCSUXIA	= 1372,
	PPC_QVSTFCSX	= 1373,
	PPC_QVSTFCSXA	= 1374,
	PPC_QVSTFCSXI	= 1375,
	PPC_QVSTFCSXIA	= 1376,
	PPC_QVSTFCSXs	= 1377,
	PPC_QVSTFDUX	= 1378,
	PPC_QVSTFDUXA	= 1379,
	PPC_QVSTFDUXI	= 1380,
	PPC_QVSTFDUXIA	= 1381,
	PPC_QVSTFDX	= 1382,
	PPC_QVSTFDXA	= 1383,
	PPC_QVSTFDXI	= 1384,
	PPC_QVSTFDXIA	= 1385,
	PPC_QVSTFDXb	= 1386,
	PPC_QVSTFIWX	= 1387,
	PPC_QVSTFIWXA	= 1388,
	PPC_QVSTFSUX	= 1389,
	PPC_QVSTFSUXA	= 1390,
	PPC_QVSTFSUXI	= 1391,
	PPC_QVSTFSUXIA	= 1392,
	PPC_QVSTFSUXs	= 1393,
	PPC_QVSTFSX	= 1394,
	PPC_QVSTFSXA	= 1395,
	PPC_QVSTFSXI	= 1396,
	PPC_QVSTFSXIA	= 1397,
	PPC_QVSTFSXs	= 1398,
	PPC_RESTORE_CR	= 1399,
	PPC_RESTORE_CRBIT	= 1400,
	PPC_RESTORE_VRSAVE	= 1401,
	PPC_RFCI	= 1402,
	PPC_RFDI	= 1403,
	PPC_RFEBB	= 1404,
	PPC_RFI	= 1405,
	PPC_RFID	= 1406,
	PPC_RFMCI	= 1407,
	PPC_RLDCL	= 1408,
	PPC_RLDCLo	= 1409,
	PPC_RLDCR	= 1410,
	PPC_RLDCRo	= 1411,
	PPC_RLDIC	= 1412,
	PPC_RLDICL	= 1413,
	PPC_RLDICL_32	= 1414,
	PPC_RLDICL_32_64	= 1415,
	PPC_RLDICL_32o	= 1416,
	PPC_RLDICLo	= 1417,
	PPC_RLDICR	= 1418,
	PPC_RLDICR_32	= 1419,
	PPC_RLDICRo	= 1420,
	PPC_RLDICo	= 1421,
	PPC_RLDIMI	= 1422,
	PPC_RLDIMIo	= 1423,
	PPC_RLWIMI	= 1424,
	PPC_RLWIMI8	= 1425,
	PPC_RLWIMI8o	= 1426,
	PPC_RLWIMIo	= 1427,
	PPC_RLWINM	= 1428,
	PPC_RLWINM8	= 1429,
	PPC_RLWINM8o	= 1430,
	PPC_RLWINMo	= 1431,
	PPC_RLWNM	= 1432,
	PPC_RLWNM8	= 1433,
	PPC_RLWNM8o	= 1434,
	PPC_RLWNMo	= 1435,
	PPC_ReadTB	= 1436,
	PPC_SC	= 1437,
	PPC_SELECT_CC_F16	= 1438,
	PPC_SELECT_CC_F4	= 1439,
	PPC_SELECT_CC_F8	= 1440,
	PPC_SELECT_CC_I4	= 1441,
	PPC_SELECT_CC_I8	= 1442,
	PPC_SELECT_CC_QBRC	= 1443,
	PPC_SELECT_CC_QFRC	= 1444,
	PPC_SELECT_CC_QSRC	= 1445,
	PPC_SELECT_CC_SPE	= 1446,
	PPC_SELECT_CC_SPE4	= 1447,
	PPC_SELECT_CC_VRRC	= 1448,
	PPC_SELECT_CC_VSFRC	= 1449,
	PPC_SELECT_CC_VSRC	= 1450,
	PPC_SELECT_CC_VSSRC	= 1451,
	PPC_SELECT_F16	= 1452,
	PPC_SELECT_F4	= 1453,
	PPC_SELECT_F8	= 1454,
	PPC_SELECT_I4	= 1455,
	PPC_SELECT_I8	= 1456,
	PPC_SELECT_QBRC	= 1457,
	PPC_SELECT_QFRC	= 1458,
	PPC_SELECT_QSRC	= 1459,
	PPC_SELECT_SPE	= 1460,
	PPC_SELECT_SPE4	= 1461,
	PPC_SELECT_VRRC	= 1462,
	PPC_SELECT_VSFRC	= 1463,
	PPC_SELECT_VSRC	= 1464,
	PPC_SELECT_VSSRC	= 1465,
	PPC_SETB	= 1466,
	PPC_SLBIA	= 1467,
	PPC_SLBIE	= 1468,
	PPC_SLBIEG	= 1469,
	PPC_SLBMFEE	= 1470,
	PPC_SLBMFEV	= 1471,
	PPC_SLBMTE	= 1472,
	PPC_SLBSYNC	= 1473,
	PPC_SLD	= 1474,
	PPC_SLDo	= 1475,
	PPC_SLW	= 1476,
	PPC_SLW8	= 1477,
	PPC_SLW8o	= 1478,
	PPC_SLWo	= 1479,
	PPC_SPELWZ	= 1480,
	PPC_SPELWZX	= 1481,
	PPC_SPESTW	= 1482,
	PPC_SPESTWX	= 1483,
	PPC_SPILL_CR	= 1484,
	PPC_SPILL_CRBIT	= 1485,
	PPC_SPILL_VRSAVE	= 1486,
	PPC_SRAD	= 1487,
	PPC_SRADI	= 1488,
	PPC_SRADI_32	= 1489,
	PPC_SRADIo	= 1490,
	PPC_SRADo	= 1491,
	PPC_SRAW	= 1492,
	PPC_SRAWI	= 1493,
	PPC_SRAWIo	= 1494,
	PPC_SRAWo	= 1495,
	PPC_SRD	= 1496,
	PPC_SRDo	= 1497,
	PPC_SRW	= 1498,
	PPC_SRW8	= 1499,
	PPC_SRW8o	= 1500,
	PPC_SRWo	= 1501,
	PPC_STB	= 1502,
	PPC_STB8	= 1503,
	PPC_STBCIX	= 1504,
	PPC_STBCX	= 1505,
	PPC_STBEPX	= 1506,
	PPC_STBU	= 1507,
	PPC_STBU8	= 1508,
	PPC_STBUX	= 1509,
	PPC_STBUX8	= 1510,
	PPC_STBX	= 1511,
	PPC_STBX8	= 1512,
	PPC_STBXTLS	= 1513,
	PPC_STBXTLS_	= 1514,
	PPC_STBXTLS_32	= 1515,
	PPC_STD	= 1516,
	PPC_STDAT	= 1517,
	PPC_STDBRX	= 1518,
	PPC_STDCIX	= 1519,
	PPC_STDCX	= 1520,
	PPC_STDU	= 1521,
	PPC_STDUX	= 1522,
	PPC_STDX	= 1523,
	PPC_STDXTLS	= 1524,
	PPC_STDXTLS_	= 1525,
	PPC_STFD	= 1526,
	PPC_STFDEPX	= 1527,
	PPC_STFDU	= 1528,
	PPC_STFDUX	= 1529,
	PPC_STFDX	= 1530,
	PPC_STFIWX	= 1531,
	PPC_STFS	= 1532,
	PPC_STFSU	= 1533,
	PPC_STFSUX	= 1534,
	PPC_STFSX	= 1535,
	PPC_STH	= 1536,
	PPC_STH8	= 1537,
	PPC_STHBRX	= 1538,
	PPC_STHCIX	= 1539,
	PPC_STHCX	= 1540,
	PPC_STHEPX	= 1541,
	PPC_STHU	= 1542,
	PPC_STHU8	= 1543,
	PPC_STHUX	= 1544,
	PPC_STHUX8	= 1545,
	PPC_STHX	= 1546,
	PPC_STHX8	= 1547,
	PPC_STHXTLS	= 1548,
	PPC_STHXTLS_	= 1549,
	PPC_STHXTLS_32	= 1550,
	PPC_STMW	= 1551,
	PPC_STOP	= 1552,
	PPC_STSWI	= 1553,
	PPC_STVEBX	= 1554,
	PPC_STVEHX	= 1555,
	PPC_STVEWX	= 1556,
	PPC_STVX	= 1557,
	PPC_STVXL	= 1558,
	PPC_STW	= 1559,
	PPC_STW8	= 1560,
	PPC_STWAT	= 1561,
	PPC_STWBRX	= 1562,
	PPC_STWCIX	= 1563,
	PPC_STWCX	= 1564,
	PPC_STWEPX	= 1565,
	PPC_STWU	= 1566,
	PPC_STWU8	= 1567,
	PPC_STWUX	= 1568,
	PPC_STWUX8	= 1569,
	PPC_STWX	= 1570,
	PPC_STWX8	= 1571,
	PPC_STWXTLS	= 1572,
	PPC_STWXTLS_	= 1573,
	PPC_STWXTLS_32	= 1574,
	PPC_STXSD	= 1575,
	PPC_STXSDX	= 1576,
	PPC_STXSIBX	= 1577,
	PPC_STXSIBXv	= 1578,
	PPC_STXSIHX	= 1579,
	PPC_STXSIHXv	= 1580,
	PPC_STXSIWX	= 1581,
	PPC_STXSSP	= 1582,
	PPC_STXSSPX	= 1583,
	PPC_STXV	= 1584,
	PPC_STXVB16X	= 1585,
	PPC_STXVD2X	= 1586,
	PPC_STXVH8X	= 1587,
	PPC_STXVL	= 1588,
	PPC_STXVLL	= 1589,
	PPC_STXVW4X	= 1590,
	PPC_STXVX	= 1591,
	PPC_SUBF	= 1592,
	PPC_SUBF8	= 1593,
	PPC_SUBF8o	= 1594,
	PPC_SUBFC	= 1595,
	PPC_SUBFC8	= 1596,
	PPC_SUBFC8o	= 1597,
	PPC_SUBFCo	= 1598,
	PPC_SUBFE	= 1599,
	PPC_SUBFE8	= 1600,
	PPC_SUBFE8o	= 1601,
	PPC_SUBFEo	= 1602,
	PPC_SUBFIC	= 1603,
	PPC_SUBFIC8	= 1604,
	PPC_SUBFME	= 1605,
	PPC_SUBFME8	= 1606,
	PPC_SUBFME8o	= 1607,
	PPC_SUBFMEo	= 1608,
	PPC_SUBFZE	= 1609,
	PPC_SUBFZE8	= 1610,
	PPC_SUBFZE8o	= 1611,
	PPC_SUBFZEo	= 1612,
	PPC_SUBFo	= 1613,
	PPC_SYNC	= 1614,
	PPC_TABORT	= 1615,
	PPC_TABORTDC	= 1616,
	PPC_TABORTDCI	= 1617,
	PPC_TABORTWC	= 1618,
	PPC_TABORTWCI	= 1619,
	PPC_TAILB	= 1620,
	PPC_TAILB8	= 1621,
	PPC_TAILBA	= 1622,
	PPC_TAILBA8	= 1623,
	PPC_TAILBCTR	= 1624,
	PPC_TAILBCTR8	= 1625,
	PPC_TBEGIN	= 1626,
	PPC_TBEGIN_RET	= 1627,
	PPC_TCHECK	= 1628,
	PPC_TCHECK_RET	= 1629,
	PPC_TCRETURNai	= 1630,
	PPC_TCRETURNai8	= 1631,
	PPC_TCRETURNdi	= 1632,
	PPC_TCRETURNdi8	= 1633,
	PPC_TCRETURNri	= 1634,
	PPC_TCRETURNri8	= 1635,
	PPC_TD	= 1636,
	PPC_TDI	= 1637,
	PPC_TEND	= 1638,
	PPC_TLBIA	= 1639,
	PPC_TLBIE	= 1640,
	PPC_TLBIEL	= 1641,
	PPC_TLBIVAX	= 1642,
	PPC_TLBLD	= 1643,
	PPC_TLBLI	= 1644,
	PPC_TLBRE	= 1645,
	PPC_TLBRE2	= 1646,
	PPC_TLBSX	= 1647,
	PPC_TLBSX2	= 1648,
	PPC_TLBSX2D	= 1649,
	PPC_TLBSYNC	= 1650,
	PPC_TLBWE	= 1651,
	PPC_TLBWE2	= 1652,
	PPC_TRAP	= 1653,
	PPC_TRECHKPT	= 1654,
	PPC_TRECLAIM	= 1655,
	PPC_TSR	= 1656,
	PPC_TW	= 1657,
	PPC_TWI	= 1658,
	PPC_UPDATE_VRSAVE	= 1659,
	PPC_UpdateGBR	= 1660,
	PPC_VABSDUB	= 1661,
	PPC_VABSDUH	= 1662,
	PPC_VABSDUW	= 1663,
	PPC_VADDCUQ	= 1664,
	PPC_VADDCUW	= 1665,
	PPC_VADDECUQ	= 1666,
	PPC_VADDEUQM	= 1667,
	PPC_VADDFP	= 1668,
	PPC_VADDSBS	= 1669,
	PPC_VADDSHS	= 1670,
	PPC_VADDSWS	= 1671,
	PPC_VADDUBM	= 1672,
	PPC_VADDUBS	= 1673,
	PPC_VADDUDM	= 1674,
	PPC_VADDUHM	= 1675,
	PPC_VADDUHS	= 1676,
	PPC_VADDUQM	= 1677,
	PPC_VADDUWM	= 1678,
	PPC_VADDUWS	= 1679,
	PPC_VAND	= 1680,
	PPC_VANDC	= 1681,
	PPC_VAVGSB	= 1682,
	PPC_VAVGSH	= 1683,
	PPC_VAVGSW	= 1684,
	PPC_VAVGUB	= 1685,
	PPC_VAVGUH	= 1686,
	PPC_VAVGUW	= 1687,
	PPC_VBPERMD	= 1688,
	PPC_VBPERMQ	= 1689,
	PPC_VCFSX	= 1690,
	PPC_VCFSX_0	= 1691,
	PPC_VCFUX	= 1692,
	PPC_VCFUX_0	= 1693,
	PPC_VCIPHER	= 1694,
	PPC_VCIPHERLAST	= 1695,
	PPC_VCLZB	= 1696,
	PPC_VCLZD	= 1697,
	PPC_VCLZH	= 1698,
	PPC_VCLZLSBB	= 1699,
	PPC_VCLZW	= 1700,
	PPC_VCMPBFP	= 1701,
	PPC_VCMPBFPo	= 1702,
	PPC_VCMPEQFP	= 1703,
	PPC_VCMPEQFPo	= 1704,
	PPC_VCMPEQUB	= 1705,
	PPC_VCMPEQUBo	= 1706,
	PPC_VCMPEQUD	= 1707,
	PPC_VCMPEQUDo	= 1708,
	PPC_VCMPEQUH	= 1709,
	PPC_VCMPEQUHo	= 1710,
	PPC_VCMPEQUW	= 1711,
	PPC_VCMPEQUWo	= 1712,
	PPC_VCMPGEFP	= 1713,
	PPC_VCMPGEFPo	= 1714,
	PPC_VCMPGTFP	= 1715,
	PPC_VCMPGTFPo	= 1716,
	PPC_VCMPGTSB	= 1717,
	PPC_VCMPGTSBo	= 1718,
	PPC_VCMPGTSD	= 1719,
	PPC_VCMPGTSDo	= 1720,
	PPC_VCMPGTSH	= 1721,
	PPC_VCMPGTSHo	= 1722,
	PPC_VCMPGTSW	= 1723,
	PPC_VCMPGTSWo	= 1724,
	PPC_VCMPGTUB	= 1725,
	PPC_VCMPGTUBo	= 1726,
	PPC_VCMPGTUD	= 1727,
	PPC_VCMPGTUDo	= 1728,
	PPC_VCMPGTUH	= 1729,
	PPC_VCMPGTUHo	= 1730,
	PPC_VCMPGTUW	= 1731,
	PPC_VCMPGTUWo	= 1732,
	PPC_VCMPNEB	= 1733,
	PPC_VCMPNEBo	= 1734,
	PPC_VCMPNEH	= 1735,
	PPC_VCMPNEHo	= 1736,
	PPC_VCMPNEW	= 1737,
	PPC_VCMPNEWo	= 1738,
	PPC_VCMPNEZB	= 1739,
	PPC_VCMPNEZBo	= 1740,
	PPC_VCMPNEZH	= 1741,
	PPC_VCMPNEZHo	= 1742,
	PPC_VCMPNEZW	= 1743,
	PPC_VCMPNEZWo	= 1744,
	PPC_VCTSXS	= 1745,
	PPC_VCTSXS_0	= 1746,
	PPC_VCTUXS	= 1747,
	PPC_VCTUXS_0	= 1748,
	PPC_VCTZB	= 1749,
	PPC_VCTZD	= 1750,
	PPC_VCTZH	= 1751,
	PPC_VCTZLSBB	= 1752,
	PPC_VCTZW	= 1753,
	PPC_VEQV	= 1754,
	PPC_VEXPTEFP	= 1755,
	PPC_VEXTRACTD	= 1756,
	PPC_VEXTRACTUB	= 1757,
	PPC_VEXTRACTUH	= 1758,
	PPC_VEXTRACTUW	= 1759,
	PPC_VEXTSB2D	= 1760,
	PPC_VEXTSB2Ds	= 1761,
	PPC_VEXTSB2W	= 1762,
	PPC_VEXTSB2Ws	= 1763,
	PPC_VEXTSH2D	= 1764,
	PPC_VEXTSH2Ds	= 1765,
	PPC_VEXTSH2W	= 1766,
	PPC_VEXTSH2Ws	= 1767,
	PPC_VEXTSW2D	= 1768,
	PPC_VEXTSW2Ds	= 1769,
	PPC_VEXTUBLX	= 1770,
	PPC_VEXTUBRX	= 1771,
	PPC_VEXTUHLX	= 1772,
	PPC_VEXTUHRX	= 1773,
	PPC_VEXTUWLX	= 1774,
	PPC_VEXTUWRX	= 1775,
	PPC_VGBBD	= 1776,
	PPC_VINSERTB	= 1777,
	PPC_VINSERTD	= 1778,
	PPC_VINSERTH	= 1779,
	PPC_VINSERTW	= 1780,
	PPC_VLOGEFP	= 1781,
	PPC_VMADDFP	= 1782,
	PPC_VMAXFP	= 1783,
	PPC_VMAXSB	= 1784,
	PPC_VMAXSD	= 1785,
	PPC_VMAXSH	= 1786,
	PPC_VMAXSW	= 1787,
	PPC_VMAXUB	= 1788,
	PPC_VMAXUD	= 1789,
	PPC_VMAXUH	= 1790,
	PPC_VMAXUW	= 1791,
	PPC_VMHADDSHS	= 1792,
	PPC_VMHRADDSHS	= 1793,
	PPC_VMINFP	= 1794,
	PPC_VMINSB	= 1795,
	PPC_VMINSD	= 1796,
	PPC_VMINSH	= 1797,
	PPC_VMINSW	= 1798,
	PPC_VMINUB	= 1799,
	PPC_VMINUD	= 1800,
	PPC_VMINUH	= 1801,
	PPC_VMINUW	= 1802,
	PPC_VMLADDUHM	= 1803,
	PPC_VMRGEW	= 1804,
	PPC_VMRGHB	= 1805,
	PPC_VMRGHH	= 1806,
	PPC_VMRGHW	= 1807,
	PPC_VMRGLB	= 1808,
	PPC_VMRGLH	= 1809,
	PPC_VMRGLW	= 1810,
	PPC_VMRGOW	= 1811,
	PPC_VMSUMMBM	= 1812,
	PPC_VMSUMSHM	= 1813,
	PPC_VMSUMSHS	= 1814,
	PPC_VMSUMUBM	= 1815,
	PPC_VMSUMUHM	= 1816,
	PPC_VMSUMUHS	= 1817,
	PPC_VMUL10CUQ	= 1818,
	PPC_VMUL10ECUQ	= 1819,
	PPC_VMUL10EUQ	= 1820,
	PPC_VMUL10UQ	= 1821,
	PPC_VMULESB	= 1822,
	PPC_VMULESH	= 1823,
	PPC_VMULESW	= 1824,
	PPC_VMULEUB	= 1825,
	PPC_VMULEUH	= 1826,
	PPC_VMULEUW	= 1827,
	PPC_VMULOSB	= 1828,
	PPC_VMULOSH	= 1829,
	PPC_VMULOSW	= 1830,
	PPC_VMULOUB	= 1831,
	PPC_VMULOUH	= 1832,
	PPC_VMULOUW	= 1833,
	PPC_VMULUWM	= 1834,
	PPC_VNAND	= 1835,
	PPC_VNCIPHER	= 1836,
	PPC_VNCIPHERLAST	= 1837,
	PPC_VNEGD	= 1838,
	PPC_VNEGW	= 1839,
	PPC_VNMSUBFP	= 1840,
	PPC_VNOR	= 1841,
	PPC_VOR	= 1842,
	PPC_VORC	= 1843,
	PPC_VPERM	= 1844,
	PPC_VPERMR	= 1845,
	PPC_VPERMXOR	= 1846,
	PPC_VPKPX	= 1847,
	PPC_VPKSDSS	= 1848,
	PPC_VPKSDUS	= 1849,
	PPC_VPKSHSS	= 1850,
	PPC_VPKSHUS	= 1851,
	PPC_VPKSWSS	= 1852,
	PPC_VPKSWUS	= 1853,
	PPC_VPKUDUM	= 1854,
	PPC_VPKUDUS	= 1855,
	PPC_VPKUHUM	= 1856,
	PPC_VPKUHUS	= 1857,
	PPC_VPKUWUM	= 1858,
	PPC_VPKUWUS	= 1859,
	PPC_VPMSUMB	= 1860,
	PPC_VPMSUMD	= 1861,
	PPC_VPMSUMH	= 1862,
	PPC_VPMSUMW	= 1863,
	PPC_VPOPCNTB	= 1864,
	PPC_VPOPCNTD	= 1865,
	PPC_VPOPCNTH	= 1866,
	PPC_VPOPCNTW	= 1867,
	PPC_VPRTYBD	= 1868,
	PPC_VPRTYBQ	= 1869,
	PPC_VPRTYBW	= 1870,
	PPC_VREFP	= 1871,
	PPC_VRFIM	= 1872,
	PPC_VRFIN	= 1873,
	PPC_VRFIP	= 1874,
	PPC_VRFIZ	= 1875,
	PPC_VRLB	= 1876,
	PPC_VRLD	= 1877,
	PPC_VRLDMI	= 1878,
	PPC_VRLDNM	= 1879,
	PPC_VRLH	= 1880,
	PPC_VRLW	= 1881,
	PPC_VRLWMI	= 1882,
	PPC_VRLWNM	= 1883,
	PPC_VRSQRTEFP	= 1884,
	PPC_VSBOX	= 1885,
	PPC_VSEL	= 1886,
	PPC_VSHASIGMAD	= 1887,
	PPC_VSHASIGMAW	= 1888,
	PPC_VSL	= 1889,
	PPC_VSLB	= 1890,
	PPC_VSLD	= 1891,
	PPC_VSLDOI	= 1892,
	PPC_VSLH	= 1893,
	PPC_VSLO	= 1894,
	PPC_VSLV	= 1895,
	PPC_VSLW	= 1896,
	PPC_VSPLTB	= 1897,
	PPC_VSPLTBs	= 1898,
	PPC_VSPLTH	= 1899,
	PPC_VSPLTHs	= 1900,
	PPC_VSPLTISB	= 1901,
	PPC_VSPLTISH	= 1902,
	PPC_VSPLTISW	= 1903,
	PPC_VSPLTW	= 1904,
	PPC_VSR	= 1905,
	PPC_VSRAB	= 1906,
	PPC_VSRAD	= 1907,
	PPC_VSRAH	= 1908,
	PPC_VSRAW	= 1909,
	PPC_VSRB	= 1910,
	PPC_VSRD	= 1911,
	PPC_VSRH	= 1912,
	PPC_VSRO	= 1913,
	PPC_VSRV	= 1914,
	PPC_VSRW	= 1915,
	PPC_VSUBCUQ	= 1916,
	PPC_VSUBCUW	= 1917,
	PPC_VSUBECUQ	= 1918,
	PPC_VSUBEUQM	= 1919,
	PPC_VSUBFP	= 1920,
	PPC_VSUBSBS	= 1921,
	PPC_VSUBSHS	= 1922,
	PPC_VSUBSWS	= 1923,
	PPC_VSUBUBM	= 1924,
	PPC_VSUBUBS	= 1925,
	PPC_VSUBUDM	= 1926,
	PPC_VSUBUHM	= 1927,
	PPC_VSUBUHS	= 1928,
	PPC_VSUBUQM	= 1929,
	PPC_VSUBUWM	= 1930,
	PPC_VSUBUWS	= 1931,
	PPC_VSUM2SWS	= 1932,
	PPC_VSUM4SBS	= 1933,
	PPC_VSUM4SHS	= 1934,
	PPC_VSUM4UBS	= 1935,
	PPC_VSUMSWS	= 1936,
	PPC_VUPKHPX	= 1937,
	PPC_VUPKHSB	= 1938,
	PPC_VUPKHSH	= 1939,
	PPC_VUPKHSW	= 1940,
	PPC_VUPKLPX	= 1941,
	PPC_VUPKLSB	= 1942,
	PPC_VUPKLSH	= 1943,
	PPC_VUPKLSW	= 1944,
	PPC_VXOR	= 1945,
	PPC_V_SET0	= 1946,
	PPC_V_SET0B	= 1947,
	PPC_V_SET0H	= 1948,
	PPC_V_SETALLONES	= 1949,
	PPC_V_SETALLONESB	= 1950,
	PPC_V_SETALLONESH	= 1951,
	PPC_WAIT	= 1952,
	PPC_WRTEE	= 1953,
	PPC_WRTEEI	= 1954,
	PPC_XOR	= 1955,
	PPC_XOR8	= 1956,
	PPC_XOR8o	= 1957,
	PPC_XORI	= 1958,
	PPC_XORI8	= 1959,
	PPC_XORIS	= 1960,
	PPC_XORIS8	= 1961,
	PPC_XORo	= 1962,
	PPC_XSABSDP	= 1963,
	PPC_XSABSQP	= 1964,
	PPC_XSADDDP	= 1965,
	PPC_XSADDQP	= 1966,
	PPC_XSADDQPO	= 1967,
	PPC_XSADDSP	= 1968,
	PPC_XSCMPEQDP	= 1969,
	PPC_XSCMPEXPDP	= 1970,
	PPC_XSCMPEXPQP	= 1971,
	PPC_XSCMPGEDP	= 1972,
	PPC_XSCMPGTDP	= 1973,
	PPC_XSCMPODP	= 1974,
	PPC_XSCMPOQP	= 1975,
	PPC_XSCMPUDP	= 1976,
	PPC_XSCMPUQP	= 1977,
	PPC_XSCPSGNDP	= 1978,
	PPC_XSCPSGNQP	= 1979,
	PPC_XSCVDPHP	= 1980,
	PPC_XSCVDPQP	= 1981,
	PPC_XSCVDPSP	= 1982,
	PPC_XSCVDPSPN	= 1983,
	PPC_XSCVDPSXDS	= 1984,
	PPC_XSCVDPSXDSs	= 1985,
	PPC_XSCVDPSXWS	= 1986,
	PPC_XSCVDPSXWSs	= 1987,
	PPC_XSCVDPUXDS	= 1988,
	PPC_XSCVDPUXDSs	= 1989,
	PPC_XSCVDPUXWS	= 1990,
	PPC_XSCVDPUXWSs	= 1991,
	PPC_XSCVHPDP	= 1992,
	PPC_XSCVQPDP	= 1993,
	PPC_XSCVQPDPO	= 1994,
	PPC_XSCVQPSDZ	= 1995,
	PPC_XSCVQPSWZ	= 1996,
	PPC_XSCVQPUDZ	= 1997,
	PPC_XSCVQPUWZ	= 1998,
	PPC_XSCVSDQP	= 1999,
	PPC_XSCVSPDP	= 2000,
	PPC_XSCVSPDPN	= 2001,
	PPC_XSCVSXDDP	= 2002,
	PPC_XSCVSXDSP	= 2003,
	PPC_XSCVUDQP	= 2004,
	PPC_XSCVUXDDP	= 2005,
	PPC_XSCVUXDSP	= 2006,
	PPC_XSDIVDP	= 2007,
	PPC_XSDIVQP	= 2008,
	PPC_XSDIVQPO	= 2009,
	PPC_XSDIVSP	= 2010,
	PPC_XSIEXPDP	= 2011,
	PPC_XSIEXPQP	= 2012,
	PPC_XSMADDADP	= 2013,
	PPC_XSMADDASP	= 2014,
	PPC_XSMADDMDP	= 2015,
	PPC_XSMADDMSP	= 2016,
	PPC_XSMADDQP	= 2017,
	PPC_XSMADDQPO	= 2018,
	PPC_XSMAXCDP	= 2019,
	PPC_XSMAXDP	= 2020,
	PPC_XSMAXJDP	= 2021,
	PPC_XSMINCDP	= 2022,
	PPC_XSMINDP	= 2023,
	PPC_XSMINJDP	= 2024,
	PPC_XSMSUBADP	= 2025,
	PPC_XSMSUBASP	= 2026,
	PPC_XSMSUBMDP	= 2027,
	PPC_XSMSUBMSP	= 2028,
	PPC_XSMSUBQP	= 2029,
	PPC_XSMSUBQPO	= 2030,
	PPC_XSMULDP	= 2031,
	PPC_XSMULQP	= 2032,
	PPC_XSMULQPO	= 2033,
	PPC_XSMULSP	= 2034,
	PPC_XSNABSDP	= 2035,
	PPC_XSNABSQP	= 2036,
	PPC_XSNEGDP	= 2037,
	PPC_XSNEGQP	= 2038,
	PPC_XSNMADDADP	= 2039,
	PPC_XSNMADDASP	= 2040,
	PPC_XSNMADDMDP	= 2041,
	PPC_XSNMADDMSP	= 2042,
	PPC_XSNMADDQP	= 2043,
	PPC_XSNMADDQPO	= 2044,
	PPC_XSNMSUBADP	= 2045,
	PPC_XSNMSUBASP	= 2046,
	PPC_XSNMSUBMDP	= 2047,
	PPC_XSNMSUBMSP	= 2048,
	PPC_XSNMSUBQP	= 2049,
	PPC_XSNMSUBQPO	= 2050,
	PPC_XSRDPI	= 2051,
	PPC_XSRDPIC	= 2052,
	PPC_XSRDPIM	= 2053,
	PPC_XSRDPIP	= 2054,
	PPC_XSRDPIZ	= 2055,
	PPC_XSREDP	= 2056,
	PPC_XSRESP	= 2057,
	PPC_XSRQPI	= 2058,
	PPC_XSRQPIX	= 2059,
	PPC_XSRQPXP	= 2060,
	PPC_XSRSP	= 2061,
	PPC_XSRSQRTEDP	= 2062,
	PPC_XSRSQRTESP	= 2063,
	PPC_XSSQRTDP	= 2064,
	PPC_XSSQRTQP	= 2065,
	PPC_XSSQRTQPO	= 2066,
	PPC_XSSQRTSP	= 2067,
	PPC_XSSUBDP	= 2068,
	PPC_XSSUBQP	= 2069,
	PPC_XSSUBQPO	= 2070,
	PPC_XSSUBSP	= 2071,
	PPC_XSTDIVDP	= 2072,
	PPC_XSTSQRTDP	= 2073,
	PPC_XSTSTDCDP	= 2074,
	PPC_XSTSTDCQP	= 2075,
	PPC_XSTSTDCSP	= 2076,
	PPC_XSXEXPDP	= 2077,
	PPC_XSXEXPQP	= 2078,
	PPC_XSXSIGDP	= 2079,
	PPC_XSXSIGQP	= 2080,
	PPC_XVABSDP	= 2081,
	PPC_XVABSSP	= 2082,
	PPC_XVADDDP	= 2083,
	PPC_XVADDSP	= 2084,
	PPC_XVCMPEQDP	= 2085,
	PPC_XVCMPEQDPo	= 2086,
	PPC_XVCMPEQSP	= 2087,
	PPC_XVCMPEQSPo	= 2088,
	PPC_XVCMPGEDP	= 2089,
	PPC_XVCMPGEDPo	= 2090,
	PPC_XVCMPGESP	= 2091,
	PPC_XVCMPGESPo	= 2092,
	PPC_XVCMPGTDP	= 2093,
	PPC_XVCMPGTDPo	= 2094,
	PPC_XVCMPGTSP	= 2095,
	PPC_XVCMPGTSPo	= 2096,
	PPC_XVCPSGNDP	= 2097,
	PPC_XVCPSGNSP	= 2098,
	PPC_XVCVDPSP	= 2099,
	PPC_XVCVDPSXDS	= 2100,
	PPC_XVCVDPSXWS	= 2101,
	PPC_XVCVDPUXDS	= 2102,
	PPC_XVCVDPUXWS	= 2103,
	PPC_XVCVHPSP	= 2104,
	PPC_XVCVSPDP	= 2105,
	PPC_XVCVSPHP	= 2106,
	PPC_XVCVSPSXDS	= 2107,
	PPC_XVCVSPSXWS	= 2108,
	PPC_XVCVSPUXDS	= 2109,
	PPC_XVCVSPUXWS	= 2110,
	PPC_XVCVSXDDP	= 2111,
	PPC_XVCVSXDSP	= 2112,
	PPC_XVCVSXWDP	= 2113,
	PPC_XVCVSXWSP	= 2114,
	PPC_XVCVUXDDP	= 2115,
	PPC_XVCVUXDSP	= 2116,
	PPC_XVCVUXWDP	= 2117,
	PPC_XVCVUXWSP	= 2118,
	PPC_XVDIVDP	= 2119,
	PPC_XVDIVSP	= 2120,
	PPC_XVIEXPDP	= 2121,
	PPC_XVIEXPSP	= 2122,
	PPC_XVMADDADP	= 2123,
	PPC_XVMADDASP	= 2124,
	PPC_XVMADDMDP	= 2125,
	PPC_XVMADDMSP	= 2126,
	PPC_XVMAXDP	= 2127,
	PPC_XVMAXSP	= 2128,
	PPC_XVMINDP	= 2129,
	PPC_XVMINSP	= 2130,
	PPC_XVMSUBADP	= 2131,
	PPC_XVMSUBASP	= 2132,
	PPC_XVMSUBMDP	= 2133,
	PPC_XVMSUBMSP	= 2134,
	PPC_XVMULDP	= 2135,
	PPC_XVMULSP	= 2136,
	PPC_XVNABSDP	= 2137,
	PPC_XVNABSSP	= 2138,
	PPC_XVNEGDP	= 2139,
	PPC_XVNEGSP	= 2140,
	PPC_XVNMADDADP	= 2141,
	PPC_XVNMADDASP	= 2142,
	PPC_XVNMADDMDP	= 2143,
	PPC_XVNMADDMSP	= 2144,
	PPC_XVNMSUBADP	= 2145,
	PPC_XVNMSUBASP	= 2146,
	PPC_XVNMSUBMDP	= 2147,
	PPC_XVNMSUBMSP	= 2148,
	PPC_XVRDPI	= 2149,
	PPC_XVRDPIC	= 2150,
	PPC_XVRDPIM	= 2151,
	PPC_XVRDPIP	= 2152,
	PPC_XVRDPIZ	= 2153,
	PPC_XVREDP	= 2154,
	PPC_XVRESP	= 2155,
	PPC_XVRSPI	= 2156,
	PPC_XVRSPIC	= 2157,
	PPC_XVRSPIM	= 2158,
	PPC_XVRSPIP	= 2159,
	PPC_XVRSPIZ	= 2160,
	PPC_XVRSQRTEDP	= 2161,
	PPC_XVRSQRTESP	= 2162,
	PPC_XVSQRTDP	= 2163,
	PPC_XVSQRTSP	= 2164,
	PPC_XVSUBDP	= 2165,
	PPC_XVSUBSP	= 2166,
	PPC_XVTDIVDP	= 2167,
	PPC_XVTDIVSP	= 2168,
	PPC_XVTSQRTDP	= 2169,
	PPC_XVTSQRTSP	= 2170,
	PPC_XVTSTDCDP	= 2171,
	PPC_XVTSTDCSP	= 2172,
	PPC_XVXEXPDP	= 2173,
	PPC_XVXEXPSP	= 2174,
	PPC_XVXSIGDP	= 2175,
	PPC_XVXSIGSP	= 2176,
	PPC_XXBRD	= 2177,
	PPC_XXBRH	= 2178,
	PPC_XXBRQ	= 2179,
	PPC_XXBRW	= 2180,
	PPC_XXEXTRACTUW	= 2181,
	PPC_XXINSERTW	= 2182,
	PPC_XXLAND	= 2183,
	PPC_XXLANDC	= 2184,
	PPC_XXLEQV	= 2185,
	PPC_XXLNAND	= 2186,
	PPC_XXLNOR	= 2187,
	PPC_XXLOR	= 2188,
	PPC_XXLORC	= 2189,
	PPC_XXLORf	= 2190,
	PPC_XXLXOR	= 2191,
	PPC_XXLXORdpz	= 2192,
	PPC_XXLXORspz	= 2193,
	PPC_XXLXORz	= 2194,
	PPC_XXMRGHW	= 2195,
	PPC_XXMRGLW	= 2196,
	PPC_XXPERM	= 2197,
	PPC_XXPERMDI	= 2198,
	PPC_XXPERMDIs	= 2199,
	PPC_XXPERMR	= 2200,
	PPC_XXSEL	= 2201,
	PPC_XXSLDWI	= 2202,
	PPC_XXSLDWIs	= 2203,
	PPC_XXSPLTIB	= 2204,
	PPC_XXSPLTW	= 2205,
	PPC_XXSPLTWs	= 2206,
	PPC_gBC	= 2207,
	PPC_gBCA	= 2208,
	PPC_gBCAat	= 2209,
	PPC_gBCCTR	= 2210,
	PPC_gBCCTRL	= 2211,
	PPC_gBCL	= 2212,
	PPC_gBCLA	= 2213,
	PPC_gBCLAat	= 2214,
	PPC_gBCLR	= 2215,
	PPC_gBCLRL	= 2216,
	PPC_gBCLat	= 2217,
	PPC_gBCat	= 2218,
	PPC_INSTRUCTION_LIST_END = 2219
};

#endif // GET_INSTRINFO_ENUM

#ifdef GET_INSTRINFO_MC_DESC
#undef GET_INSTRINFO_MC_DESC

#define nullptr 0

static const MCOperandInfo OperandInfo2[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo3[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo4[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo5[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo6[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo7[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo8[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo9[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo10[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo11[] = { { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo12[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo13[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo14[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo15[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo16[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo17[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo18[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo19[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo20[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo21[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo22[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo23[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo24[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo25[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, };
static const MCOperandInfo OperandInfo26[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, };
static const MCOperandInfo OperandInfo27[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo28[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, };
static const MCOperandInfo OperandInfo29[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, };
static const MCOperandInfo OperandInfo30[] = { { -1, 0, MCOI_OPERAND_GENERIC_0, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_1, 0 }, { -1, 0, MCOI_OPERAND_GENERIC_2, 0 }, };
static const MCOperandInfo OperandInfo31[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo32[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo33[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo34[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo35[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo36[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo37[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo38[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo39[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo40[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo41[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo42[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo43[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo44[] = { { PPC_SPILLTOVSRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo45[] = { { PPC_SPILLTOVSRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo46[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo47[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo48[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo49[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo50[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo51[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo52[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo53[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo54[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo55[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo56[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo57[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo58[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo59[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo60[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo61[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo62[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo63[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo64[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo65[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo66[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo67[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo68[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo69[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo70[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo71[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo72[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo73[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo74[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo75[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo76[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo77[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo78[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo79[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo80[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo81[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo82[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo83[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo84[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo85[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo86[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo87[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo88[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo89[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo90[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo91[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo92[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo93[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo94[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo95[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo96[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo97[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo98[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo99[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo100[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo101[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo102[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo103[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo104[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo105[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo106[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo107[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo108[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo109[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo110[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo111[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo112[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo113[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo114[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo115[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo116[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo117[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo118[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo119[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo120[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo121[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo122[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo123[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo124[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo125[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo126[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo127[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo128[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo129[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo130[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo131[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo132[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo133[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo134[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo135[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo136[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo137[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo138[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo139[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo140[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo141[] = { { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo142[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo143[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo144[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo145[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo146[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo147[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo148[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo149[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo150[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo151[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo152[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo153[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo154[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRSAVERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo155[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo156[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo157[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo158[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo159[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo160[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo161[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo162[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo163[] = { { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo164[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo165[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo166[] = { { PPC_VRSAVERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo167[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo168[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo169[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo170[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo171[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo172[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo173[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo174[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo175[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo176[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo177[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo178[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo179[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo180[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo181[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo182[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo183[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo184[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo185[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo186[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo187[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo188[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo189[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo190[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo191[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo192[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo193[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo194[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo195[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo196[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo197[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo198[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((1 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo199[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo200[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo201[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo202[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo203[] = { { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo204[] = { { PPC_VRSAVERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo205[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo206[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo207[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo208[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo209[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo210[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo211[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo212[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo213[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo214[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo215[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo216[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo217[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo218[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo219[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo220[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo221[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo222[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo223[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo224[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo225[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo226[] = { { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo227[] = { { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo228[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRC_NOR0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo229[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RC_NOX0RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo230[] = { { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QBRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo231[] = { { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo232[] = { { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_QSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo233[] = { { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPERCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo234[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo235[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo236[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo237[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo238[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo239[] = { { PPC_SPE4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo240[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo241[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo242[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo243[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo244[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo245[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_F8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo246[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo247[] = { { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, { PPC_F4RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { 1, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { 0, 0|(1<<MCOI_LookupPtrRegClass), MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo248[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo249[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo250[] = { { PPC_CTRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo251[] = { { PPC_CTRRC8RegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo252[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo253[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo254[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };
static const MCOperandInfo OperandInfo255[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo256[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo257[] = { { PPC_GPRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo258[] = { { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo259[] = { { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo260[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo261[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, };
static const MCOperandInfo OperandInfo262[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo263[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo264[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo265[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo266[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo267[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo268[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo269[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo270[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo271[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo272[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo273[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo274[] = { { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo275[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo276[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo277[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_G8RCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo278[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo279[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo280[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo281[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo282[] = { { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo283[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo284[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo285[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo286[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo287[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo288[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo289[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo290[] = { { PPC_CRRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo291[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo292[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo293[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, ((0 << 16) | (1 << MCOI_TIED_TO)) }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo294[] = { { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo295[] = { { PPC_VSSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo296[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo297[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo298[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo299[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, };
static const MCOperandInfo OperandInfo300[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo301[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo302[] = { { PPC_VSRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { PPC_VFRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo303[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo304[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, };
static const MCOperandInfo OperandInfo305[] = { { -1, 0, MCOI_OPERAND_UNKNOWN, 0 }, { PPC_CRBITRCRegClassID, 0, MCOI_OPERAND_REGISTER, 0 }, { -1, 0, MCOI_OPERAND_IMMEDIATE, 0 }, };

static const MCInstrDesc PPCInsts[] = {
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 1, OperandInfo3 },
  { 1, OperandInfo3 },
  { 1, OperandInfo3 },
  { 1, OperandInfo3 },
  { 0, nullptr },
  { 3, OperandInfo4 },
  { 4, OperandInfo5 },
  { 1, OperandInfo2 },
  { 4, OperandInfo6 },
  { 3, OperandInfo4 },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 2, OperandInfo7 },
  { 2, OperandInfo7 },
  { 0, nullptr },
  { 1, OperandInfo3 },
  { 1, OperandInfo3 },
  { 2, OperandInfo8 },
  { 1, OperandInfo2 },
  { 6, OperandInfo9 },
  { 1, OperandInfo10 },
  { 0, nullptr },
  { 2, OperandInfo11 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 2, OperandInfo11 },
  { 3, OperandInfo12 },
  { 1, OperandInfo2 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 1, OperandInfo14 },
  { 1, OperandInfo14 },
  { 2, OperandInfo15 },
  { 2, OperandInfo15 },
  { 3, OperandInfo16 },
  { 2, OperandInfo17 },
  { 4, OperandInfo18 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 5, OperandInfo19 },
  { 4, OperandInfo20 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 3, OperandInfo21 },
  { 2, OperandInfo15 },
  { 1, OperandInfo14 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo15 },
  { 2, OperandInfo15 },
  { 1, OperandInfo14 },
  { 3, OperandInfo16 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 4, OperandInfo22 },
  { 4, OperandInfo22 },
  { 4, OperandInfo20 },
  { 5, OperandInfo23 },
  { 5, OperandInfo23 },
  { 4, OperandInfo20 },
  { 4, OperandInfo20 },
  { 4, OperandInfo20 },
  { 4, OperandInfo20 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 4, OperandInfo24 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 3, OperandInfo13 },
  { 2, OperandInfo25 },
  { 2, OperandInfo25 },
  { 2, OperandInfo25 },
  { 2, OperandInfo25 },
  { 2, OperandInfo25 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo17 },
  { 2, OperandInfo25 },
  { 3, OperandInfo26 },
  { 3, OperandInfo27 },
  { 1, OperandInfo2 },
  { 4, OperandInfo28 },
  { 3, OperandInfo29 },
  { 4, OperandInfo30 },
  { 2, OperandInfo25 },
  { 2, OperandInfo17 },
  { 2, OperandInfo15 },
  { 1, OperandInfo31 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 3, OperandInfo38 },
  { 3, OperandInfo38 },
  { 3, OperandInfo38 },
  { 3, OperandInfo38 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 3, OperandInfo39 },
  { 3, OperandInfo40 },
  { 3, OperandInfo39 },
  { 3, OperandInfo40 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo33 },
  { 3, OperandInfo41 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 4, OperandInfo43 },
  { 4, OperandInfo43 },
  { 4, OperandInfo43 },
  { 4, OperandInfo43 },
  { 4, OperandInfo43 },
  { 4, OperandInfo43 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo44 },
  { 3, OperandInfo45 },
  { 3, OperandInfo44 },
  { 3, OperandInfo45 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo42 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 2, OperandInfo46 },
  { 3, OperandInfo47 },
  { 3, OperandInfo42 },
  { 3, OperandInfo47 },
  { 3, OperandInfo42 },
  { 3, OperandInfo48 },
  { 3, OperandInfo35 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo50 },
  { 3, OperandInfo34 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo51 },
  { 3, OperandInfo50 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo51 },
  { 3, OperandInfo50 },
  { 3, OperandInfo50 },
  { 3, OperandInfo51 },
  { 3, OperandInfo50 },
  { 3, OperandInfo50 },
  { 3, OperandInfo50 },
  { 3, OperandInfo50 },
  { 3, OperandInfo50 },
  { 3, OperandInfo51 },
  { 3, OperandInfo50 },
  { 3, OperandInfo51 },
  { 4, OperandInfo52 },
  { 4, OperandInfo53 },
  { 3, OperandInfo50 },
  { 3, OperandInfo51 },
  { 4, OperandInfo52 },
  { 4, OperandInfo53 },
  { 3, OperandInfo50 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo55 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo7 },
  { 2, OperandInfo7 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 2, OperandInfo56 },
  { 2, OperandInfo57 },
  { 2, OperandInfo56 },
  { 2, OperandInfo57 },
  { 3, OperandInfo48 },
  { 5, OperandInfo58 },
  { 5, OperandInfo58 },
  { 5, OperandInfo59 },
  { 5, OperandInfo58 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo60 },
  { 4, OperandInfo61 },
  { 4, OperandInfo60 },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 2, OperandInfo62 },
  { 3, OperandInfo63 },
  { 3, OperandInfo63 },
  { 2, OperandInfo64 },
  { 2, OperandInfo64 },
  { 2, OperandInfo64 },
  { 2, OperandInfo64 },
  { 3, OperandInfo63 },
  { 3, OperandInfo63 },
  { 2, OperandInfo64 },
  { 2, OperandInfo64 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 3, OperandInfo66 },
  { 3, OperandInfo66 },
  { 3, OperandInfo66 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 3, OperandInfo66 },
  { 3, OperandInfo66 },
  { 4, OperandInfo69 },
  { 4, OperandInfo69 },
  { 4, OperandInfo69 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo62 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 1, OperandInfo2 },
  { 2, OperandInfo62 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 2, OperandInfo70 },
  { 2, OperandInfo62 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 2, OperandInfo7 },
  { 2, OperandInfo7 },
  { 2, OperandInfo7 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 2, OperandInfo7 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 0, nullptr },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo71 },
  { 3, OperandInfo72 },
  { 3, OperandInfo73 },
  { 3, OperandInfo71 },
  { 3, OperandInfo72 },
  { 3, OperandInfo74 },
  { 3, OperandInfo75 },
  { 4, OperandInfo76 },
  { 4, OperandInfo76 },
  { 3, OperandInfo74 },
  { 3, OperandInfo75 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 0, nullptr },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 0, nullptr },
  { 0, nullptr },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 3, OperandInfo77 },
  { 1, OperandInfo65 },
  { 1, OperandInfo65 },
  { 3, OperandInfo77 },
  { 3, OperandInfo63 },
  { 2, OperandInfo55 },
  { 2, OperandInfo37 },
  { 3, OperandInfo78 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 3, OperandInfo78 },
  { 3, OperandInfo38 },
  { 3, OperandInfo78 },
  { 3, OperandInfo38 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 2, OperandInfo36 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 3, OperandInfo79 },
  { 3, OperandInfo80 },
  { 3, OperandInfo79 },
  { 3, OperandInfo80 },
  { 3, OperandInfo79 },
  { 3, OperandInfo80 },
  { 3, OperandInfo79 },
  { 3, OperandInfo80 },
  { 4, OperandInfo81 },
  { 4, OperandInfo82 },
  { 3, OperandInfo83 },
  { 3, OperandInfo83 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 2, OperandInfo86 },
  { 2, OperandInfo86 },
  { 2, OperandInfo87 },
  { 2, OperandInfo87 },
  { 2, OperandInfo86 },
  { 2, OperandInfo87 },
  { 2, OperandInfo87 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 2, OperandInfo86 },
  { 2, OperandInfo89 },
  { 2, OperandInfo89 },
  { 2, OperandInfo89 },
  { 2, OperandInfo86 },
  { 2, OperandInfo89 },
  { 2, OperandInfo89 },
  { 2, OperandInfo89 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 2, OperandInfo90 },
  { 3, OperandInfo91 },
  { 2, OperandInfo92 },
  { 2, OperandInfo90 },
  { 2, OperandInfo93 },
  { 2, OperandInfo90 },
  { 2, OperandInfo93 },
  { 3, OperandInfo94 },
  { 3, OperandInfo94 },
  { 3, OperandInfo94 },
  { 2, OperandInfo90 },
  { 2, OperandInfo95 },
  { 2, OperandInfo95 },
  { 2, OperandInfo86 },
  { 2, OperandInfo95 },
  { 2, OperandInfo95 },
  { 3, OperandInfo91 },
  { 3, OperandInfo91 },
  { 2, OperandInfo90 },
  { 2, OperandInfo90 },
  { 3, OperandInfo91 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 1, OperandInfo96 },
  { 1, OperandInfo96 },
  { 2, OperandInfo97 },
  { 2, OperandInfo97 },
  { 1, OperandInfo2 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 2, OperandInfo84 },
  { 3, OperandInfo98 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo88 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo98 },
  { 2, OperandInfo84 },
  { 4, OperandInfo101 },
  { 3, OperandInfo85 },
  { 3, OperandInfo98 },
  { 2, OperandInfo102 },
  { 2, OperandInfo102 },
  { 3, OperandInfo98 },
  { 3, OperandInfo98 },
  { 3, OperandInfo85 },
  { 3, OperandInfo85 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 3, OperandInfo99 },
  { 3, OperandInfo100 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 2, OperandInfo84 },
  { 3, OperandInfo85 },
  { 3, OperandInfo103 },
  { 3, OperandInfo85 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo104 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo104 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 3, OperandInfo34 },
  { 3, OperandInfo34 },
  { 2, OperandInfo36 },
  { 2, OperandInfo104 },
  { 2, OperandInfo104 },
  { 2, OperandInfo54 },
  { 0, nullptr },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 3, OperandInfo107 },
  { 3, OperandInfo108 },
  { 3, OperandInfo108 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 2, OperandInfo105 },
  { 2, OperandInfo109 },
  { 2, OperandInfo109 },
  { 2, OperandInfo105 },
  { 2, OperandInfo109 },
  { 2, OperandInfo109 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 3, OperandInfo110 },
  { 3, OperandInfo111 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo108 },
  { 3, OperandInfo108 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 3, OperandInfo107 },
  { 3, OperandInfo108 },
  { 3, OperandInfo108 },
  { 3, OperandInfo107 },
  { 4, OperandInfo112 },
  { 4, OperandInfo113 },
  { 4, OperandInfo113 },
  { 4, OperandInfo112 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 4, OperandInfo112 },
  { 4, OperandInfo113 },
  { 4, OperandInfo113 },
  { 4, OperandInfo112 },
  { 3, OperandInfo107 },
  { 3, OperandInfo108 },
  { 3, OperandInfo108 },
  { 3, OperandInfo107 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 4, OperandInfo112 },
  { 4, OperandInfo113 },
  { 4, OperandInfo113 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo113 },
  { 4, OperandInfo113 },
  { 4, OperandInfo112 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo109 },
  { 2, OperandInfo109 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo114 },
  { 4, OperandInfo114 },
  { 2, OperandInfo105 },
  { 2, OperandInfo106 },
  { 2, OperandInfo106 },
  { 2, OperandInfo105 },
  { 3, OperandInfo107 },
  { 3, OperandInfo108 },
  { 3, OperandInfo108 },
  { 3, OperandInfo107 },
  { 3, OperandInfo110 },
  { 2, OperandInfo115 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 0, nullptr },
  { 2, OperandInfo37 },
  { 2, OperandInfo37 },
  { 3, OperandInfo78 },
  { 3, OperandInfo78 },
  { 3, OperandInfo78 },
  { 3, OperandInfo78 },
  { 2, OperandInfo36 },
  { 4, OperandInfo116 },
  { 4, OperandInfo117 },
  { 0, nullptr },
  { 3, OperandInfo51 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo48 },
  { 4, OperandInfo120 },
  { 4, OperandInfo121 },
  { 4, OperandInfo122 },
  { 4, OperandInfo123 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 3, OperandInfo119 },
  { 3, OperandInfo124 },
  { 3, OperandInfo124 },
  { 3, OperandInfo34 },
  { 3, OperandInfo124 },
  { 3, OperandInfo48 },
  { 3, OperandInfo124 },
  { 4, OperandInfo121 },
  { 4, OperandInfo123 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo127 },
  { 3, OperandInfo128 },
  { 3, OperandInfo129 },
  { 3, OperandInfo129 },
  { 3, OperandInfo129 },
  { 3, OperandInfo129 },
  { 3, OperandInfo127 },
  { 3, OperandInfo130 },
  { 3, OperandInfo131 },
  { 4, OperandInfo132 },
  { 4, OperandInfo133 },
  { 3, OperandInfo131 },
  { 3, OperandInfo131 },
  { 3, OperandInfo131 },
  { 3, OperandInfo134 },
  { 4, OperandInfo135 },
  { 4, OperandInfo136 },
  { 3, OperandInfo137 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 4, OperandInfo120 },
  { 4, OperandInfo121 },
  { 4, OperandInfo122 },
  { 4, OperandInfo123 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo118 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo48 },
  { 4, OperandInfo120 },
  { 4, OperandInfo121 },
  { 4, OperandInfo122 },
  { 4, OperandInfo123 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 2, OperandInfo138 },
  { 2, OperandInfo46 },
  { 2, OperandInfo138 },
  { 2, OperandInfo46 },
  { 3, OperandInfo41 },
  { 3, OperandInfo35 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo119 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 3, OperandInfo35 },
  { 4, OperandInfo123 },
  { 3, OperandInfo124 },
  { 3, OperandInfo118 },
  { 3, OperandInfo41 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo118 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo48 },
  { 4, OperandInfo120 },
  { 4, OperandInfo121 },
  { 4, OperandInfo122 },
  { 4, OperandInfo123 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 3, OperandInfo140 },
  { 3, OperandInfo141 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 3, OperandInfo141 },
  { 3, OperandInfo47 },
  { 3, OperandInfo142 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo144 },
  { 3, OperandInfo144 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 4, OperandInfo145 },
  { 4, OperandInfo145 },
  { 4, OperandInfo145 },
  { 1, OperandInfo2 },
  { 2, OperandInfo146 },
  { 2, OperandInfo146 },
  { 1, OperandInfo147 },
  { 3, OperandInfo148 },
  { 1, OperandInfo149 },
  { 1, OperandInfo31 },
  { 1, OperandInfo149 },
  { 1, OperandInfo31 },
  { 2, OperandInfo150 },
  { 1, OperandInfo151 },
  { 2, OperandInfo105 },
  { 2, OperandInfo152 },
  { 1, OperandInfo151 },
  { 2, OperandInfo105 },
  { 2, OperandInfo152 },
  { 1, OperandInfo151 },
  { 1, OperandInfo151 },
  { 1, OperandInfo149 },
  { 1, OperandInfo31 },
  { 1, OperandInfo149 },
  { 2, OperandInfo138 },
  { 2, OperandInfo46 },
  { 2, OperandInfo150 },
  { 2, OperandInfo150 },
  { 2, OperandInfo55 },
  { 2, OperandInfo138 },
  { 2, OperandInfo36 },
  { 2, OperandInfo150 },
  { 1, OperandInfo31 },
  { 2, OperandInfo153 },
  { 1, OperandInfo149 },
  { 2, OperandInfo154 },
  { 1, OperandInfo155 },
  { 2, OperandInfo156 },
  { 2, OperandInfo157 },
  { 2, OperandInfo158 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 0, nullptr },
  { 0, nullptr },
  { 2, OperandInfo159 },
  { 2, OperandInfo160 },
  { 1, OperandInfo149 },
  { 1, OperandInfo31 },
  { 1, OperandInfo31 },
  { 1, OperandInfo149 },
  { 2, OperandInfo150 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 4, OperandInfo161 },
  { 3, OperandInfo162 },
  { 3, OperandInfo162 },
  { 2, OperandInfo163 },
  { 4, OperandInfo161 },
  { 1, OperandInfo149 },
  { 1, OperandInfo31 },
  { 2, OperandInfo150 },
  { 2, OperandInfo150 },
  { 2, OperandInfo164 },
  { 2, OperandInfo165 },
  { 2, OperandInfo159 },
  { 2, OperandInfo159 },
  { 2, OperandInfo160 },
  { 2, OperandInfo138 },
  { 2, OperandInfo36 },
  { 1, OperandInfo149 },
  { 2, OperandInfo166 },
  { 1, OperandInfo155 },
  { 2, OperandInfo167 },
  { 3, OperandInfo168 },
  { 2, OperandInfo169 },
  { 2, OperandInfo170 },
  { 2, OperandInfo169 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 0, nullptr },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo48 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 1, OperandInfo149 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 5, OperandInfo171 },
  { 5, OperandInfo171 },
  { 5, OperandInfo172 },
  { 5, OperandInfo172 },
  { 5, OperandInfo171 },
  { 5, OperandInfo171 },
  { 5, OperandInfo172 },
  { 5, OperandInfo172 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo110 },
  { 3, OperandInfo110 },
  { 3, OperandInfo110 },
  { 3, OperandInfo110 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 2, OperandInfo105 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 3, OperandInfo107 },
  { 3, OperandInfo107 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo112 },
  { 4, OperandInfo173 },
  { 4, OperandInfo174 },
  { 4, OperandInfo175 },
  { 3, OperandInfo176 },
  { 3, OperandInfo177 },
  { 3, OperandInfo178 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 3, OperandInfo181 },
  { 3, OperandInfo181 },
  { 3, OperandInfo182 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo183 },
  { 3, OperandInfo181 },
  { 3, OperandInfo184 },
  { 3, OperandInfo185 },
  { 3, OperandInfo181 },
  { 3, OperandInfo184 },
  { 3, OperandInfo185 },
  { 3, OperandInfo181 },
  { 3, OperandInfo184 },
  { 3, OperandInfo185 },
  { 3, OperandInfo181 },
  { 3, OperandInfo182 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo183 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 4, OperandInfo173 },
  { 4, OperandInfo174 },
  { 4, OperandInfo174 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo187 },
  { 2, OperandInfo179 },
  { 2, OperandInfo183 },
  { 2, OperandInfo180 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo187 },
  { 3, OperandInfo181 },
  { 3, OperandInfo181 },
  { 3, OperandInfo182 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo187 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo187 },
  { 4, OperandInfo186 },
  { 4, OperandInfo188 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 2, OperandInfo179 },
  { 2, OperandInfo189 },
  { 2, OperandInfo179 },
  { 2, OperandInfo179 },
  { 2, OperandInfo180 },
  { 4, OperandInfo186 },
  { 4, OperandInfo190 },
  { 4, OperandInfo191 },
  { 4, OperandInfo192 },
  { 3, OperandInfo181 },
  { 3, OperandInfo181 },
  { 3, OperandInfo182 },
  { 3, OperandInfo181 },
  { 3, OperandInfo184 },
  { 3, OperandInfo185 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 3, OperandInfo181 },
  { 3, OperandInfo181 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 4, OperandInfo186 },
  { 2, OperandInfo193 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo195 },
  { 4, OperandInfo196 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo197 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 4, OperandInfo198 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo197 },
  { 3, OperandInfo195 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 2, OperandInfo199 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo195 },
  { 4, OperandInfo200 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo197 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 4, OperandInfo201 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 4, OperandInfo200 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo194 },
  { 3, OperandInfo195 },
  { 3, OperandInfo202 },
  { 3, OperandInfo203 },
  { 3, OperandInfo204 },
  { 0, nullptr },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 0, nullptr },
  { 4, OperandInfo205 },
  { 4, OperandInfo205 },
  { 4, OperandInfo205 },
  { 4, OperandInfo205 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo206 },
  { 4, OperandInfo33 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 4, OperandInfo33 },
  { 4, OperandInfo32 },
  { 4, OperandInfo32 },
  { 5, OperandInfo207 },
  { 5, OperandInfo207 },
  { 6, OperandInfo208 },
  { 6, OperandInfo209 },
  { 6, OperandInfo209 },
  { 6, OperandInfo208 },
  { 5, OperandInfo210 },
  { 5, OperandInfo211 },
  { 5, OperandInfo211 },
  { 5, OperandInfo210 },
  { 5, OperandInfo212 },
  { 5, OperandInfo213 },
  { 5, OperandInfo213 },
  { 5, OperandInfo212 },
  { 2, OperandInfo36 },
  { 1, OperandInfo3 },
  { 5, OperandInfo214 },
  { 5, OperandInfo215 },
  { 5, OperandInfo216 },
  { 5, OperandInfo217 },
  { 5, OperandInfo218 },
  { 5, OperandInfo219 },
  { 5, OperandInfo220 },
  { 5, OperandInfo221 },
  { 5, OperandInfo222 },
  { 5, OperandInfo223 },
  { 5, OperandInfo214 },
  { 5, OperandInfo216 },
  { 5, OperandInfo224 },
  { 5, OperandInfo215 },
  { 4, OperandInfo225 },
  { 4, OperandInfo226 },
  { 4, OperandInfo227 },
  { 4, OperandInfo228 },
  { 4, OperandInfo229 },
  { 4, OperandInfo230 },
  { 4, OperandInfo231 },
  { 4, OperandInfo232 },
  { 4, OperandInfo233 },
  { 4, OperandInfo234 },
  { 4, OperandInfo225 },
  { 4, OperandInfo227 },
  { 4, OperandInfo235 },
  { 4, OperandInfo226 },
  { 2, OperandInfo236 },
  { 0, nullptr },
  { 1, OperandInfo149 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 0, nullptr },
  { 3, OperandInfo237 },
  { 3, OperandInfo237 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo238 },
  { 3, OperandInfo239 },
  { 3, OperandInfo238 },
  { 3, OperandInfo239 },
  { 3, OperandInfo202 },
  { 3, OperandInfo203 },
  { 3, OperandInfo204 },
  { 3, OperandInfo237 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo237 },
  { 3, OperandInfo48 },
  { 3, OperandInfo35 },
  { 3, OperandInfo35 },
  { 3, OperandInfo48 },
  { 3, OperandInfo237 },
  { 3, OperandInfo237 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo48 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 4, OperandInfo240 },
  { 4, OperandInfo241 },
  { 4, OperandInfo242 },
  { 4, OperandInfo243 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 3, OperandInfo119 },
  { 3, OperandInfo34 },
  { 3, OperandInfo124 },
  { 3, OperandInfo48 },
  { 3, OperandInfo124 },
  { 4, OperandInfo241 },
  { 4, OperandInfo243 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo130 },
  { 3, OperandInfo131 },
  { 4, OperandInfo244 },
  { 4, OperandInfo245 },
  { 3, OperandInfo131 },
  { 3, OperandInfo131 },
  { 3, OperandInfo134 },
  { 4, OperandInfo246 },
  { 4, OperandInfo247 },
  { 3, OperandInfo137 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo118 },
  { 3, OperandInfo48 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 4, OperandInfo240 },
  { 4, OperandInfo241 },
  { 4, OperandInfo242 },
  { 4, OperandInfo243 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 3, OperandInfo41 },
  { 0, nullptr },
  { 3, OperandInfo35 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo139 },
  { 3, OperandInfo41 },
  { 3, OperandInfo119 },
  { 3, OperandInfo35 },
  { 3, OperandInfo118 },
  { 3, OperandInfo48 },
  { 3, OperandInfo118 },
  { 3, OperandInfo118 },
  { 4, OperandInfo240 },
  { 4, OperandInfo241 },
  { 4, OperandInfo242 },
  { 4, OperandInfo243 },
  { 3, OperandInfo118 },
  { 3, OperandInfo124 },
  { 3, OperandInfo125 },
  { 3, OperandInfo125 },
  { 3, OperandInfo126 },
  { 3, OperandInfo141 },
  { 3, OperandInfo42 },
  { 3, OperandInfo42 },
  { 3, OperandInfo139 },
  { 3, OperandInfo42 },
  { 3, OperandInfo139 },
  { 3, OperandInfo42 },
  { 3, OperandInfo141 },
  { 3, OperandInfo47 },
  { 3, OperandInfo142 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo144 },
  { 3, OperandInfo144 },
  { 3, OperandInfo143 },
  { 3, OperandInfo143 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo48 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 2, OperandInfo36 },
  { 2, OperandInfo54 },
  { 2, OperandInfo54 },
  { 2, OperandInfo36 },
  { 3, OperandInfo48 },
  { 1, OperandInfo3 },
  { 1, OperandInfo149 },
  { 3, OperandInfo79 },
  { 3, OperandInfo248 },
  { 3, OperandInfo79 },
  { 3, OperandInfo248 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 0, nullptr },
  { 1, OperandInfo2 },
  { 2, OperandInfo138 },
  { 1, OperandInfo147 },
  { 1, OperandInfo149 },
  { 2, OperandInfo249 },
  { 2, OperandInfo249 },
  { 2, OperandInfo249 },
  { 2, OperandInfo249 },
  { 2, OperandInfo250 },
  { 2, OperandInfo251 },
  { 3, OperandInfo252 },
  { 3, OperandInfo253 },
  { 1, OperandInfo2 },
  { 0, nullptr },
  { 2, OperandInfo36 },
  { 1, OperandInfo149 },
  { 2, OperandInfo36 },
  { 1, OperandInfo149 },
  { 1, OperandInfo149 },
  { 0, nullptr },
  { 3, OperandInfo254 },
  { 2, OperandInfo36 },
  { 3, OperandInfo48 },
  { 3, OperandInfo48 },
  { 0, nullptr },
  { 0, nullptr },
  { 3, OperandInfo254 },
  { 0, nullptr },
  { 0, nullptr },
  { 1, OperandInfo149 },
  { 1, OperandInfo2 },
  { 3, OperandInfo79 },
  { 3, OperandInfo248 },
  { 2, OperandInfo36 },
  { 3, OperandInfo48 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo257 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo257 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 3, OperandInfo256 },
  { 3, OperandInfo256 },
  { 3, OperandInfo256 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 2, OperandInfo258 },
  { 2, OperandInfo68 },
  { 2, OperandInfo258 },
  { 2, OperandInfo68 },
  { 2, OperandInfo258 },
  { 2, OperandInfo68 },
  { 2, OperandInfo258 },
  { 2, OperandInfo68 },
  { 2, OperandInfo258 },
  { 3, OperandInfo259 },
  { 3, OperandInfo259 },
  { 3, OperandInfo259 },
  { 3, OperandInfo259 },
  { 3, OperandInfo259 },
  { 3, OperandInfo259 },
  { 2, OperandInfo68 },
  { 4, OperandInfo260 },
  { 3, OperandInfo256 },
  { 4, OperandInfo260 },
  { 3, OperandInfo256 },
  { 2, OperandInfo68 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo261 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo261 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 4, OperandInfo255 },
  { 4, OperandInfo262 },
  { 4, OperandInfo262 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo69 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo256 },
  { 3, OperandInfo263 },
  { 3, OperandInfo256 },
  { 3, OperandInfo263 },
  { 2, OperandInfo264 },
  { 2, OperandInfo264 },
  { 2, OperandInfo264 },
  { 3, OperandInfo256 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 4, OperandInfo255 },
  { 4, OperandInfo255 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 3, OperandInfo67 },
  { 1, OperandInfo155 },
  { 1, OperandInfo155 },
  { 1, OperandInfo155 },
  { 1, OperandInfo155 },
  { 1, OperandInfo155 },
  { 1, OperandInfo155 },
  { 1, OperandInfo3 },
  { 1, OperandInfo149 },
  { 1, OperandInfo3 },
  { 3, OperandInfo48 },
  { 3, OperandInfo49 },
  { 3, OperandInfo49 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo35 },
  { 3, OperandInfo34 },
  { 3, OperandInfo48 },
  { 2, OperandInfo265 },
  { 2, OperandInfo68 },
  { 3, OperandInfo266 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo267 },
  { 3, OperandInfo268 },
  { 3, OperandInfo269 },
  { 3, OperandInfo270 },
  { 3, OperandInfo268 },
  { 3, OperandInfo268 },
  { 3, OperandInfo269 },
  { 3, OperandInfo270 },
  { 3, OperandInfo269 },
  { 3, OperandInfo270 },
  { 3, OperandInfo266 },
  { 3, OperandInfo67 },
  { 2, OperandInfo265 },
  { 2, OperandInfo271 },
  { 2, OperandInfo265 },
  { 2, OperandInfo272 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 2, OperandInfo265 },
  { 2, OperandInfo274 },
  { 2, OperandInfo274 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo271 },
  { 2, OperandInfo265 },
  { 2, OperandInfo275 },
  { 2, OperandInfo265 },
  { 2, OperandInfo276 },
  { 2, OperandInfo271 },
  { 2, OperandInfo265 },
  { 2, OperandInfo276 },
  { 3, OperandInfo266 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo267 },
  { 3, OperandInfo277 },
  { 3, OperandInfo278 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo281 },
  { 4, OperandInfo281 },
  { 3, OperandInfo268 },
  { 3, OperandInfo266 },
  { 3, OperandInfo268 },
  { 3, OperandInfo268 },
  { 3, OperandInfo266 },
  { 3, OperandInfo268 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo281 },
  { 4, OperandInfo281 },
  { 3, OperandInfo266 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo267 },
  { 2, OperandInfo265 },
  { 2, OperandInfo68 },
  { 2, OperandInfo265 },
  { 2, OperandInfo68 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo281 },
  { 4, OperandInfo281 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo279 },
  { 4, OperandInfo280 },
  { 4, OperandInfo281 },
  { 4, OperandInfo281 },
  { 2, OperandInfo265 },
  { 2, OperandInfo265 },
  { 2, OperandInfo265 },
  { 2, OperandInfo265 },
  { 2, OperandInfo265 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 4, OperandInfo282 },
  { 4, OperandInfo282 },
  { 4, OperandInfo282 },
  { 2, OperandInfo276 },
  { 2, OperandInfo265 },
  { 2, OperandInfo273 },
  { 2, OperandInfo265 },
  { 2, OperandInfo68 },
  { 2, OperandInfo68 },
  { 2, OperandInfo273 },
  { 3, OperandInfo266 },
  { 3, OperandInfo67 },
  { 3, OperandInfo67 },
  { 3, OperandInfo267 },
  { 3, OperandInfo269 },
  { 2, OperandInfo283 },
  { 3, OperandInfo284 },
  { 3, OperandInfo285 },
  { 3, OperandInfo284 },
  { 2, OperandInfo156 },
  { 2, OperandInfo68 },
  { 2, OperandInfo156 },
  { 2, OperandInfo68 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 4, OperandInfo288 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo289 },
  { 3, OperandInfo289 },
  { 2, OperandInfo290 },
  { 2, OperandInfo290 },
  { 3, OperandInfo291 },
  { 3, OperandInfo291 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 2, OperandInfo286 },
  { 3, OperandInfo292 },
  { 4, OperandInfo293 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo266 },
  { 3, OperandInfo287 },
  { 1, OperandInfo294 },
  { 1, OperandInfo295 },
  { 1, OperandInfo296 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 3, OperandInfo287 },
  { 4, OperandInfo297 },
  { 3, OperandInfo298 },
  { 3, OperandInfo287 },
  { 4, OperandInfo299 },
  { 4, OperandInfo297 },
  { 3, OperandInfo298 },
  { 2, OperandInfo300 },
  { 3, OperandInfo301 },
  { 3, OperandInfo302 },
  { 3, OperandInfo303 },
  { 3, OperandInfo303 },
  { 4, OperandInfo304 },
  { 3, OperandInfo305 },
  { 3, OperandInfo305 },
  { 3, OperandInfo303 },
  { 3, OperandInfo303 },
  { 4, OperandInfo304 },
  { 3, OperandInfo305 },
  { 3, OperandInfo305 },
  { 4, OperandInfo304 },
  { 4, OperandInfo304 },
};

#endif // GET_INSTRINFO_MC_DESC
